# Ant Design Pro Vue 3

基于 Vue 3、TypeScript、Vite 和 Ant Design Vue 构建的企业级中后台管理系统。

## 技术栈

- **前端框架：** Vue 3
- **开发语言：** TypeScript
- **构建工具：** Vite
- **UI 框架：** Ant Design Vue 3.1.0
- **状态管理：** Vuex
- **路由管理：** Vue Router
- **HTTP 客户端：** Axios
- **国际化：** vue-i18n
- **图表：** ECharts

## 项目结构

```
src/
├── api/                # API 接口定义
├── assets/            # 静态资源
├── components/        # 公共组件
├── config/            # 配置文件
├── hooks/             # Vue 组合式 API hooks
├── layouts/           # 布局组件
├── locales/           # 国际化语言包
├── router/            # 路由配置
├── store/             # Vuex 状态管理
├── utils/             # 工具函数
└── views/             # 页面组件
```

## 主要功能模块

### 1. 系统管理

- 用户管理
  - 用户日志查询
  - 在线用户查询
- 参数管理
  - 机构层级管理
  - 系统配置

### 2. 流程管理

- 分支流程管理
  - 分支节点设置

### 3. 业务管理

- 科目管理
  - 科目维护

### 4. 报表合并

- 报表合并参数维护
- 报表查询

### 5. 柜面业务

- 对私开户
- 子账户开户
- 授权查询

### 6. 组件示例

- 日期选择器示例
- 自定义组件展示

## 开发环境设置

```bash
# 安装依赖
npm install

# 启动开发服务器
npm run dev

# 构建生产版本
npm run build

# 运行测试
npm run test
```

## 环境要求

- Node.js >= 14
- npm >= 6

## 浏览器支持

- 现代浏览器
- Chrome >= 64
- Firefox >= 78
- Safari >= 12
- Edge >= 79

## 特性

- 📦 开箱即用的高质量组件
- 📱 响应式设计，支持多端适配
- 🔗 基于 TypeScript 的类型安全
- 🌐 内置国际化支持
- 🎨 可定制的主题和布局
- 🔐 完善的权限管理
- 📊 集成 ECharts 图表功能
- 🚀 基于 Vite 的快速开发体验

## 开发规范

- 遵循 Vue 3 组合式 API 最佳实践
- 使用 TypeScript 进行类型检查
- 遵循 ESLint 和 Prettier 代码规范
- 组件和工具函数需要编写注释和文档

## 贡献指南

1. Fork 本仓库
2. 创建特性分支
3. 提交你的改动
4. 推送到你的分支
5. 创建 Pull Request

## 许可证

[MIT](LICENSE)
