import { ref, reactive } from 'vue'
import PlatformLogger from "@/views/front/platfrom/common/LogSystem/PlatformLogger";
import { PageFactory } from '@/views/front/platfrom/presentation/PageFunctions/PageFactory'
import { EntryBase } from '../ContractBase/EntryBase';
// import { TradeAPIsHelper } from '../ContractBase/TradeAPIsHelper';
import { PageBase } from "@/views/front/develop/Contract/ContractBase/PageBase"
import { IPage } from "@/views/front/platfrom/presentation/Interfaces/Ipage";
import { ServiceSettings } from "@/views/front/develop/ServiceProxy.Ext/ServiceSettings"
import TradePageExtension from "@/views/front/develop/Library.Ext/Function/TradePageExtension";

/**
 * 现金冠字号管理入口类
 */
export class CashCodeEntry extends EntryBase {
    //#region 静态成员
    private static readonly _action_: string = "Trade.OperationManage.CASHVIEWER";

    /**
     * 是否启用冠字号管理功能
     */
    public static Enabled: boolean;

    /**
     * 最后结束时间
     */
    public static lastendTime: string;

    /**
     * 历史业务记录
     */
    public static History: Array<CashCodeEntry.BizItem>;

    /**
     * 静态构造函数
     */
    static {
        CashCodeEntry.Enabled = ServiceSettings.GetConfig("CashCodeManage", false);
        CashCodeEntry.History = new Array<CashCodeEntry.BizItem>();
    }

    /**
     * 初始化冠字号设备
     * @param target 目标页面
     * @returns 是否初始化成功
     */
    public static Init(target: IPage): boolean {
        if (!CashCodeEntry.Enabled) return true;
        let flag: boolean = false;
        // try {
        // 初始化点钞机节点程序
        const page: any = PageFactory.CreatePage(CashCodeEntry._action_);
        //hulei_todo 不做处理点钞机
        //     while (true) {
        //         target.OwnerContainer.ModalInvoke(() => {
        //             flag = page.InitDevice();
        //         }, "链接冠字号设备，请稍候...");

        //         if (flag) break;

        //         const i: number = target.ShowComfirmBox("链接冠字号设备失败，是否重试？", ["重试", "关闭功能", "稍后处理"]);
        //         if (i == 2) CashCodeEntry.Enabled = false;
        //         if (i != 1) break;
        //     }
        // } catch (ex) {
        //     PlatformLogger.SystemErrorInfo("CashCodeEntry.InitDevice:发生异常！", ex);
        //     // throw new Error("初始化现金冠字号程序失败！");
        // }
        return flag;
    }
    //#endregion

    //#region 实例成员
    /**
     * 预处理时的柜员钱箱余额
     */
    public Bals2Init: { [key: string]: number };

    /**
     * 当前处理的Item对象
     */
    public Item: CashCodeEntry.BizItem;

    /**
     * 构造函数
     */
    constructor() {
        super();
        this.Item = new CashCodeEntry.BizItem();
        this.Item.StartTime = new Date();
    }

    /**
     * 预处理
     * @param cardNo 卡号
     * @param userName 用户名
     * @param biz 业务类型
     * @returns 是否预处理成功
     */
    Preview(cardNo: string, userName: string, biz: CashCodeEntry.BizType): boolean {
        if (!CashCodeEntry.Enabled) return true;

        // if (this.TradeBus["__StartTime__"] !== null && this.TradeBus["__StartTime__"] !== undefined && this.TradeBus["__StartTime__"] !== "") {
        //     this.Item.StartTime = new Date(
        //         parseInt(this.TradeBus["__StartTime__"].substring(0, 4)),
        //         parseInt(this.TradeBus["__StartTime__"].substring(4, 6)) - 1,
        //         parseInt(this.TradeBus["__StartTime__"].substring(6, 8)),
        //         parseInt(this.TradeBus["__StartTime__"].substring(8, 10)),
        //         parseInt(this.TradeBus["__StartTime__"].substring(10, 12)),
        //         parseInt(this.TradeBus["__StartTime__"].substring(12, 14))
        //     );
        // }

        // this.Item.CardNo = cardNo;
        // this.Item.UserName = userName;
        // this.Item.Biz = biz;
        // this.Item.TxCode = this.PageData.TradeModel.Code;

        // const dict: { [key: string]: string } = {};
        // // 登记入库
        // // if (this.PageData.TradeAPIs.TraderecordsExp("CashCodeEntry", JSON.stringify(dict)))
        // // {
        // const current = this.PageData.GetTellerBalanceMoney();
        // if (current != null) {
        //     this.Bals2Init = current;
        //     // 打印后触发
        //     this.PageData.PagePrinted.removeEventListener(this.PageData_PagePrinted);
        //     this.PageData.PagePrinted.addEventListener(this.PageData_PagePrinted);
        //     return true;
        // }
        // }
        return false;
    }

    /**
     * 页面打印事件处理
     * @param sender 发送者
     * @param e 事件参数
     */
    private PageData_PagePrinted = (sender: any): void => {
        // this.Proc(e.PrintAttr.SerialNumber);
    }

    /**
     * 业务处理
     * @param serialNo 交易流水号
     */
    private Proc(serialNo: string): void {
        if (!CashCodeEntry.Enabled) return;
        // 未调用Preview，不触发
        if (this.Bals2Init == null) return;

        this.Item.SerialNo = serialNo;
        // this.Item.EndTime = new Date();

        // // 检查余额变化，目前仅检测人民币
        // const current = this.PageData.GetTellerBalanceMoney();
        // this.Item.Money = current["01"] - this.Bals2Init["01"];

        // if (this.Item.Money != 0 || this.Item.Biz == CashCodeEntry.BizType.Counterfeit) { // 假币收缴业务不会影响钱箱
        //     // History.Add(this.Item);
        //     while (true) {
        //         // 提示处理
        //         // if (this.PageData.TradeAPIs.ShowQuestionMessageBox("本次交易存在现金处理，是否进行现金冠字号处理？\n是：立即提交\n否：等待下一笔业务提交") == System.Windows.MessageBoxResult.No)
        //         //     break;
        //         const key = this.TradeAPIs.ShowComfirmBox(
        //             "本次交易存在现金处理，是否进行现金冠字号处理？\n",
        //             "立即提交",
        //             "等待下一笔业务提交",
        //             "该交易无点钞操作无需处理"
        //         );

        //         if (key == 3) break;

        //         CashCodeEntry.History.push(this.Item);

        //         if (key != 1) break;

        //         // 弹窗处理业务
        //         const guid = this.PageData.OpenTradePage(
        //             CashCodeEntry._action_,
        //             TradePageExtension.OpenOptions.Dialog,
        //             { "STATUS_CASHVIEWER": "init" },
        //             null,
        //             "现金业务-冠字号管理"
        //         );

        //         const status = this.PageData.ViewStateData["STATUS_CASHVIEWER"] as string;
        //         // 已提交或取消，跳出循环
        //         if (status == "commit" || status == "cancel")
        //             break;
        //     }
        // }
    }
    //#endregion
}

/**
 * CashCodeEntry命名空间，包含相关类型定义
 */
export namespace CashCodeEntry {
    /**
     * 业务类型枚举
     */
    export enum BizType {
        /**
         * 存款业务
         */
        Deposit = 0,

        /**
         * 取款业务
         */
        Withdrawal = 1,

        /**
         * 残缺币兑换
         */
        Incomplete = 4,

        /**
         * 假币收缴
         */
        Counterfeit = 5,

        /**
         * 其他
         */
        Other = 6,
    }

    /**
     * 业务项目类
     */
    export class BizItem {
        /**
         * 业务开始办理时间
         */
        public StartTime: Date | null;

        /**
         * 业务结束办理时间
         */
        public EndTime: Date | null;

        /**
         * 业务类型
         */
        public Biz: BizType;

        /**
         * 交易卡号
         */
        public CardNo: string;

        /**
         * 用户名称
         */
        public UserName: string;

        /**
         * 交易金额
         */
        public Money: number;

        /**
         * 柜面交易码
         */
        public TxCode: string;

        /**
         * 交易流水
         */
        public SerialNo: string;
    }

    /**
     * 扩展业务项目类
     */
    export class MyBizItem extends BizItem {
        /**
         * 设置业务项目的所有属性
         * @param startTime 开始时间
         * @param endTime 结束时间
         * @param biz 业务类型
         * @param cardNo 卡号
         * @param userName 用户名
         * @param money 金额
         * @param txCode 交易码
         * @param serialNo 流水号
         */
        public MyMethod(
            startTime: Date,
            endTime: Date,
            biz: BizType,
            cardNo: string,
            userName: string,
            money: number,
            txCode: string,
            serialNo: string
        ): void {
            this.StartTime = startTime;
            this.EndTime = endTime;
            this.Biz = biz;
            this.CardNo = cardNo;
            this.UserName = userName;
            this.Money = money;
            this.TxCode = txCode;
            this.SerialNo = serialNo;
        }
    }
}
