import { TFInput, TFOutput } from './TFBase'

/**
 * ATM待清机金额
 * 根据相关要素，返回ATM清机现金金额
 */
export class ATMAmountClearing extends TFOutput {
    // #region Output
    /**
     * 清机金额 0400
     * (null)
     */
    public QJJE: string = ''

    /**
     * 标志位 0730
     * 第一位[0]验证是否有清机记录(0-有 1-无)
     */
    public BZW: string = ''

    /**
     * ATM柜员
     * (null)
     */
    public ATMTEL: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * ATM柜员号 0920
         * (null) 
         */
        public ATMGYH: string = ''

        /**
         * ATM清钞编号
         * (null) 
         */
        public ATMQCNO: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new ATMAmountClearing()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K051"
            this.MessageData.Fd92 = this.ATMGYH
            this.MessageData.Fd58 = this.ATMQCNO

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.QJJE = this.MessageData.Fd40
            output.BZW = this.MessageData.Fd73
            output.ATMTEL = this.MessageData.Fd92

            return output
        }
    }
    // #endregion
}

/**
 * 创建ATM待清机金额功能的Vue 3组合式API封装
 */
export function useATMAmountClearing() {
    /**
     * 获取ATM待清机金额
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const getATMAmountClearing = (
        params: {
            ATMGYH: string,   // ATM柜员号
            ATMQCNO: string   // ATM清钞编号
        },
        page: any
    ): ATMAmountClearing => {
        const input = new ATMAmountClearing.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<ATMAmountClearing>(page)
    }

    return {
        getATMAmountClearing
    }
}
