import { TFInput, TFOutput } from './TFBase'

/**
 * 查询账户扣划利息
 * 通过账号查询账户扣划未提取利息
 */
export class CheckAccountDeducInterest extends TFOutput {
    // #region Output
    /**
     * 未提扣划利息 0400
     * (null)
     */
    public WTKHLX: string = ''

    /**
     * 有扣划利息的扣划记录笔数 0500
     * 
     */
    public YJLBS: string = ''

    /**
     * 扣划记录总笔数 0510
     * 
     */
    public KHZBS: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 账号 0300
         * (null) 
         */
        public ZH: string = ''

        /**
         * 账户序号 0340
         * (null) 
         */
        public ZHXH: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new CheckAccountDeducInterest()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K036"
            this.MessageData.Fd30 = this.ZH
            this.MessageData.Fd34 = this.ZHXH

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.WTKHLX = this.MessageData.Fd40
            output.YJLBS = this.MessageData.Fd50
            output.KHZBS = this.MessageData.Fd51

            return output
        }
    }
    // #endregion
}

/**
 * 创建查询账户扣划利息功能的Vue 3组合式API封装
 */
export function useCheckAccountDeducInterest() {
    /**
     * 查询账户扣划利息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const checkAccountDeducInterest = (
        params: {
            ZH: string,       // 账号
            ZHXH?: string     // 账户序号
        },
        page: any
    ): CheckAccountDeducInterest => {
        const input = new CheckAccountDeducInterest.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<CheckAccountDeducInterest>(page)
    }

    return {
        checkAccountDeducInterest
    }
}
