import { TFInput, TFOutput } from './TFBase'

/**
 * 与平台通讯，查询账户黑白名单状态
 * 黑名单-阻断，灰名单-提示，白名单-通过
 */
export class CheckAccountStat extends TFOutput {
    // #region Output
    /**
     * 账户状态 0350
     * 0-通过，1-阻断，2-提示
     */
    public ZHZT: string = ''

    /**
     * 描述 0760
     * null
     */
    public MS: string = ''

    /**
     * 返回信息 0130
     * null
     */
    public FHXX: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 业务种类 0900
         * A-取现,B-存现,C-转账,D-汇款,E-介质更换
         */
        public YWZL: string = ''

        /**
         * 账号 0300
         * (null) 
         */
        public ZH: string = ''

        /**
         * 户名 0250
         * (null) 
         */
        public ZHHM: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new CheckAccountStat()
            this.MessageData.BitMapType = "Agn"
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "0701"
            this.MessageData.Fd28 = "100701"
            this.MessageData.Fd18 = "GJFC"
            this.MessageData.Fd89 = "01"
            this.MessageData.Fd90 = this.YWZL
            this.MessageData.Fd30 = this.ZH
            this.MessageData.Fd25 = this.ZHHM

            // 检查配置值
            if (this.PageData.TradeAPIs.GetConfigValueByConfigID("488aafd20ec440a988fe4b8e3d71a641") !== "1") {
                output.ZHZT = "0"
                return output
            }

            this.PageData.TradeAPIs.CallAgn(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.ZHZT = this.MessageData.Fd35
            output.MS = this.MessageData.Fd76
            output.FHXX = this.MessageData.Fd13

            return output
        }
    }
    // #endregion
}

/**
 * 创建查询账户黑白名单状态功能的Vue 3组合式API封装
 */
export function useCheckAccountStat() {
    /**
     * 查询账户黑白名单状态
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const checkAccountStat = (
        params: {
            YWZL: string,     // 业务种类：A-取现,B-存现,C-转账,D-汇款,E-介质更换
            ZH: string,       // 账号
            ZHHM?: string     // 户名
        },
        page: any
    ): CheckAccountStat => {
        const input = new CheckAccountStat.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<CheckAccountStat>(page)
    }

    return {
        checkAccountStat
    }
}
