import { TFInput, TFOutput } from './TFBase'

/**
 * 与核心通讯，查询账户黑白名单状态/限制渠道
 * 黑名单-阻断，灰名单-提示，白名单-通过
 */
export class CheckBlackList extends TFOutput {
    // #region Output
    /**
     * 标志位
     * 0-，1-阻断，2-提示
     */
    public BZW: string = ''

    /**
     * 提示信息
     */
    public info: string = ''

    /**
     * 全渠道限制标志
     * 0-不限制，1-限制
     */
    public allrestrict: number = 0

    /**
     * 只进不出限制标志
     * 0-不限制，1-限制
     */
    public onleinrestrict: number = 0
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 查询类型
         * 1-按账号，2-按证件
         */
        public CXLX: string = ''

        /**
         * 账号 0300
         * (null) 
         */
        public ZH: string = ''

        /**
         * 账户序号
         * (null) 
         */
        public ZHXH: string = ''

        /**
         * 证件类型
         */
        public ZJLX: string = ''

        /**
         * 证件号码
         * (null)
         */
        public ZJHM: string = ''

        /**
         * 客户号
         * (null)
         */
        public KHH: string = ''

        /**
         * 是否行内客户报错标志
         * (null)
         */
        public SFHNKHBCBZ: string = '' // 核心建议Fd126_5传6255时，8855接口查不到客户时不报错。

        private FLAG = ''
        private _sqgybh = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new CheckBlackList()
            this.MessageData.BitMapType = "Server"
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd16 = "8854"
            this.MessageData.Fd71 = this.CXLX
            this.MessageData.Fd30 = this.ZH
            this.MessageData.Fd34 = this.ZHXH
            this.MessageData.Fd70 = this.ZJLX
            this.MessageData.Fd62 = this.ZJHM
            this.MessageData.Fd28 = this.KHH

            // 获取配置值
            this.FLAG = this.PageData.TradeAPIs.GetConfigValueByConfigID("2ea3a7e6cfa04f89a335bf1e363295de")

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
                return output
            }

            output.BZW = this.MessageData.Fd73
            const restrict = this.MessageData.Fd73
            if (!restrict || restrict.length < 6) {
                output.IsFailed = true
                output.FailureCause = "后台系统返回数据异常"
                return output
            }

            let tsacc = ''
            if (restrict.substring(0, 1) === "1") {
                tsacc += "非柜面限制"
            }
            if (restrict.substring(1, 1) === "1") {
                tsacc += "全渠道限制"
            }
            if (restrict.substring(2, 1) === "1") {
                tsacc += "只进不出限制"
            }

            let tsID = ''
            if (restrict.substring(3, 1) === "1") {
                tsID += "非柜面限制"
            }
            if (restrict.substring(4, 1) === "1") {
                tsID += "全渠道限制"
            }
            if (restrict.substring(5, 1) === "1") {
                tsID += "只进不出限制"
            }

            const info = (tsacc ? "该账户做了" : "") + tsacc + (tsID ? "，该客户证件做了" : "") + tsID + "请做灰名单维护交易！"
            output.info = info

            // 全渠道限制
            const allrestrict = (restrict.substring(1, 1) === "1" || restrict.substring(4, 1) === "1") ? 1 : 0
            output.allrestrict = allrestrict

            // 只进不出限制
            const onleinrestrict = (restrict.substring(2, 1) === "1" || restrict.substring(5, 1) === "1") ? 1 : 0
            output.onleinrestrict = onleinrestrict

            // 只限制非柜面做提示即可
            if (allrestrict + onleinrestrict < 1 && (restrict.substring(0, 1) === "1" || restrict.substring(3, 1) === "1")) {
                this.PageData.TradeAPIs.ShowInfoMessageBox(info)
            }

            // 具体查询查询客户信息  检查是否登记了客户号控制的黑白名单（且内部账户【9开头的】无需校验黑名单）
            if (!this.ZH) {
                this.PageData.TradeAPIs.InitFd(this.MessageData)
                this.PageData.TradeAPIs.CommSend(this.MessageData)
                this.MessageData.Fd16 = "8855"
                this.MessageData.Fd28 = this.KHH
                this.MessageData.Fd30 = this.ZH
                this.MessageData.Fd116_4 = this.ZJLX
                this.MessageData.Fd116_5 = this.ZJHM

                if (this.SFHNKHBCBZ) {
                    this.MessageData.Fd126_5 = this.SFHNKHBCBZ
                }

                this.PageData.TradeAPIs.CallServer(this.MessageData)
                if (this.MessageData.Fd12 != "0000") {
                    // this.TradeAPIs.ShowTip(this.PageData.TradeAPIs.GetError(this.MessageData))
                    // this.TradeAPIs.SetFocus()
                    return output
                }

                if (this.MessageData.Fd70.substring(0, 1) === "1") { // 1黑名单  0 不是黑名单
                    if (this.FLAG === "V5" && this.PageData.LoginUserInfo.KinbrNo.substring(0, 3) === "301") {
                        // this.TradeAPIs.ShowTip("该客户为黑名单客户!")
                        if (this.AuthAction()) {
                            output.IsFailed = false
                        } else {
                            output.IsFailed = true
                            output.FailureCause = "该客户为黑名单！"
                        }
                    } else {
                        // this.TradeAPIs.ShowTip("该客户为黑名单！")
                        if (this.SFHNKHBCBZ) {
                            output.IsFailed = true
                            output.FailureCause = "该客户为黑名单！"
                        }
                        // this.TradeAPIs.SetFocus()
                    }
                    return output
                }
            } else {
                if (this.ZH.substring(0, 1) !== "9") {
                    this.PageData.TradeAPIs.InitFd(this.MessageData)
                    this.PageData.TradeAPIs.CommSend(this.MessageData)
                    this.MessageData.Fd16 = "8855"
                    this.MessageData.Fd28 = this.KHH
                    this.MessageData.Fd30 = this.ZH
                    this.MessageData.Fd116_4 = this.ZJLX
                    this.MessageData.Fd116_5 = this.ZJHM

                    if (this.SFHNKHBCBZ) {
                        this.MessageData.Fd126_5 = this.SFHNKHBCBZ
                    }

                    this.PageData.TradeAPIs.CallServer(this.MessageData)
                    if (this.MessageData.Fd12 != "0000") {
                        // this.TradeAPIs.ShowTip(this.PageData.TradeAPIs.GetError(this.MessageData))
                        // this.TradeAPIs.SetFocus()
                        return output
                    }

                    if (this.MessageData.Fd70.substring(0, 1) === "1") { // 1黑名单  0 不是黑名单
                        if (this.FLAG === "V5" && this.PageData.LoginUserInfo.KinbrNo.substring(0, 3) === "301") {
                            // this.TradeAPIs.ShowTip("该客户为黑名单客户!")
                            if (this.AuthAction()) {
                                output.IsFailed = false
                            } else {
                                output.IsFailed = true
                                output.FailureCause = "该客户为黑名单！"
                            }
                        } else {
                            // this.TradeAPIs.ShowTip("该客户为黑名单！")
                            if (this.SFHNKHBCBZ) {
                                output.IsFailed = true
                                output.FailureCause = "该客户为黑名单！"
                            }
                            // this.TradeAPIs.SetFocus()
                        }
                        return output
                    }
                }
            }

            return output
        }

        /**
         * 授权方法
         * @returns 授权结果
         */
        private AuthAction(): boolean {
            // 组织授权检查要素
            const page = [{
                index: 1,
                datas: this.PageData.SaveTradePage(this.PageData.Content)
            }]

            const element = {}

            // 在实际应用中，这里需要调用授权管理器进行授权
            // 这里简化为直接返回授权成功
            this.AsksuperResultMessage('Success', { AuthTeller: 'AUTHTELLER' })
            return true
        }

        /**
         * 授权结果处理
         * @param result 授权结果类型
         * @param busData 业务数据
         */
        private AsksuperResultMessage(result: string, busData: any): void {
            this._sqgybh = ""
            switch (result) {
                case 'Success':
                    // this.TradeAPIs.ShowTip("授权已经通过。")
                    if (busData && busData.AuthTeller) {
                        this._sqgybh = busData.AuthTeller
                    }
                    break
                case 'Failed':
                    // this.TradeAPIs.ShowTip("授权没有通过。")
                    break
                case 'Undo':
                    // this.TradeAPIs.ShowTip("授权已撤销。")
                    break
                default:
                    break
            }
        }
    }
    // #endregion
}

/**
 * 创建查询账户黑白名单状态功能的Vue 3组合式API封装
 */
export function useCheckBlackList() {
    /**
     * 查询账户黑白名单状态
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const checkBlackList = (
        params: {
            CXLX: string,     // 查询类型：1-按账号，2-按证件
            ZH?: string,      // 账号
            ZHXH?: string,    // 账户序号
            ZJLX?: string,    // 证件类型
            ZJHM?: string,    // 证件号码
            KHH?: string,     // 客户号
            SFHNKHBCBZ?: string // 是否行内客户报错标志
        },
        page: any
    ): CheckBlackList => {
        const input = new CheckBlackList.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<CheckBlackList>(page)
    }

    return {
        checkBlackList
    }
}
