import { TFInput, TFOutput } from './TFBase'

/**
 * 查询黑名单（DQS版本）
 */
export class CheckBlackList_DQS extends TFOutput {
    // #region Output
    /**
     * 1黑名单  0 不是黑名单
     * null
     */
    public Result: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 账号 0300
         * (null) 
         */
        public ZH: string = ''

        /**
         * 账户序号
         * (null) 
         */
        public ZHXH: string = ''

        /**
         * 证件类型
         */
        public ZJLX: string = ''

        /**
         * 证件号码
         * (null)
         */
        public ZJHM: string = ''

        /**
         * 客户号
         * (null)
         */
        public KHH: string = ''

        /**
         * 是否行内客户报错标志
         * (null)
         */
        public SFHNKHBCBZ: string = '' // 核心建议Fd126_5传6255时，8855接口查不到客户时不报错。

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new CheckBlackList_DQS()
            this.MessageData.BitMapType = "Server"
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd16 = "8855"
            this.MessageData.Fd28 = this.KHH
            this.MessageData.Fd30 = this.ZH
            this.MessageData.Fd116_4 = this.ZJLX
            this.MessageData.Fd116_5 = this.ZJHM

            if (this.SFHNKHBCBZ) {
                this.MessageData.Fd126_5 = this.SFHNKHBCBZ
            }

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                // this.TradeAPIs.ShowTip(this.PageData.TradeAPIs.GetError(this.MessageData))
                // this.TradeAPIs.SetFocus() hulei_处理报错
                return output
            }

            if (this.MessageData.Fd70.substring(0, 1) === "1") { // 1黑名单  0 不是黑名单
                // this.TradeAPIs.ShowTip("该客户为黑名单！")
                if (this.SFHNKHBCBZ) {
                    output.IsFailed = true
                    output.FailureCause = "该客户为黑名单！"
                }
                // this.TradeAPIs.SetFocus()
                return output
            }

            output.Result = this.MessageData.Fd70.substring(0, 1)
            return output
        }
    }
    // #endregion
}

/**
 * 创建查询黑名单功能的Vue 3组合式API封装
 */
export function useCheckBlackList_DQS() {
    /**
     * 查询黑名单
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const checkBlackList_DQS = (
        params: {
            ZH?: string,      // 账号
            ZHXH?: string,    // 账户序号
            ZJLX?: string,    // 证件类型
            ZJHM?: string,    // 证件号码
            KHH?: string,     // 客户号
            SFHNKHBCBZ?: string // 是否行内客户报错标志
        },
        page: any
    ): CheckBlackList_DQS => {
        const input = new CheckBlackList_DQS.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<CheckBlackList_DQS>(page)
    }

    return {
        checkBlackList_DQS
    }
}
