import { TFInput, TFOutput } from './TFBase'

/**
 * 检查客户凭证
 * 客户凭证查询
 */
export class CheckCustomerCertificate extends TFOutput {
    // #region Output
    /**
     * 凭证状态 0700
     * 0无 1出售未使用 2挂失 3回收 4作废 5使用
     */
    public PZZT: string = ''

    /**
     * 出售日期 0440
     */
    public CSRQ: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 账号 0300
         * (null) 
         */
        public ZH: string = ''

        /**
         * 凭证号码 0580
         * (null) 
         */
        public PZHM: string = ''

        /**
         * 凭证类型 0890
         * (null) 
         */
        public PZLX: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new CheckCustomerCertificate()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K035"
            this.MessageData.Fd30 = this.ZH
            this.MessageData.Fd58 = this.PZHM
            this.MessageData.Fd89 = this.PZLX

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.PZZT = this.DelSpace(this.MessageData.Fd70)
            output.CSRQ = this.DelSpace(this.MessageData.Fd44)

            return output
        }
    }
    // #endregion
}

/**
 * 创建检查客户凭证功能的Vue 3组合式API封装
 */
export function useCheckCustomerCertificate() {
    /**
     * 检查客户凭证
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const checkCustomerCertificate = (
        params: {
            ZH: string,      // 账号
            PZHM: string,    // 凭证号码
            PZLX: string     // 凭证类型
        },
        page: any
    ): CheckCustomerCertificate => {
        const input = new CheckCustomerCertificate.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<CheckCustomerCertificate>(page)
    }

    return {
        checkCustomerCertificate
    }
}
