import { TFInput, TFOutput } from './TFBase'

/**
 * 检查灰名单
 */
export class CheckGreyList extends TFOutput {
    // #region Output
    /**
     * 1 有限制 0 无限制
     * null
     */
    public Result: string = ''

    /**
     * 标志位
     * bit[0]:0-不限制，1-限制非柜面  bit[1]:0--不限制，1-限制全渠道  bit[2]:0-不限制，1-限制只进不出
     */
    public BZW: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 账号 0300
         * (null) 
         */
        public ZH: string = ''

        /**
         * 账户序号
         * (null) 
         */
        public ZHXH: string = ''

        /**
         * 证件类型
         */
        public ZJLX: string = ''

        /**
         * 证件号码
         * (null)
         */
        public ZJHM: string = ''

        /**
         * 客户号
         * (null)
         */
        public KHH: string = ''

        /**
         * 单位编号
         * (null)
         */
        public DWBH: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new CheckGreyList()
            this.MessageData.BitMapType = "Server"
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd16 = "8857"
            this.MessageData.Fd28 = this.KHH
            this.MessageData.Fd30 = this.ZH
            this.MessageData.Fd116_4 = this.ZJLX
            this.MessageData.Fd116_5 = this.ZJHM
            this.MessageData.Fd64 = this.DWBH

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                // this.TradeAPIs.ShowTip(this.PageData.TradeAPIs.GetError(this.MessageData))
                // this.TradeAPIs.SetFocus() hulei_弹窗提示
                return output
            }

            // output.BZW = (this.MessageData.Fd73)
            output.Result = this.MessageData.Fd70.substring(0, 1)
            return output
        }
    }
    // #endregion
}

/**
 * 创建检查灰名单功能的Vue 3组合式API封装
 */
export function useCheckGreyList() {
    /**
     * 检查灰名单
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const checkGreyList = (
        params: {
            ZH?: string,      // 账号
            ZHXH?: string,    // 账户序号
            ZJLX?: string,    // 证件类型
            ZJHM?: string,    // 证件号码
            KHH?: string,     // 客户号
            DWBH?: string     // 单位编号
        },
        page: any
    ): CheckGreyList => {
        const input = new CheckGreyList.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<CheckGreyList>(page)
    }

    return {
        checkGreyList
    }
}
