import { TFInput, TFOutput } from './TFBase'

/**
 * 根据质押总编号查询关联总金额和总数量
 */
export class CheckStatusPledge extends TFOutput {
    // #region Output
    /**
     * 关联总金额 0390
     */
    public GLZJE: string = ''

    /**
     * 关联质押物总质押金额 0400
     */
    public GLZYWZZYJE: string = ''

    /**
     * 关联质押物编号数量 0480
     */
    public GLZYWBHSL: string = ''

    /**
     * 关联质押物总数量 0490
     */
    public GLZYWZSL: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 质押总编号 0320
         */
        public ZYZBH: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new CheckStatusPledge()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K010"
            this.MessageData.Fd32 = this.ZYZBH

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.GLZJE = this.DelSpace(this.MessageData.Fd39)
            output.GLZYWZZYJE = this.DelSpace(this.MessageData.Fd40)
            output.GLZYWBHSL = this.DelSpace(this.MessageData.Fd48)
            output.GLZYWZSL = this.DelSpace(this.MessageData.Fd49)

            return output
        }
    }
    // #endregion
}

/**
 * 创建质押状态查询功能的Vue 3组合式API封装
 */
export function useCheckStatusPledge() {
    /**
     * 根据质押总编号查询关联总金额和总数量
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const checkStatusPledge = (
        params: {
            ZYZBH: string    // 质押总编号
        },
        page: any
    ): CheckStatusPledge => {
        const input = new CheckStatusPledge.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<CheckStatusPledge>(page)
    }

    return {
        checkStatusPledge
    }
}
