import { TFInput, TFOutput } from './TFBase'

/**
 * 交易规则检查
 * 交易规则检查,账户序号检查，根据交易代码,账号,交易金额检查是否超出限额
 */
export class CheckTradeRule extends TFOutput {
    // #region Output
    // 无特定输出属性，只有基类的 IsFailed 和 FailureCause
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 目标交易代码 0120
         * 主交易代码 
         */
        public MBJYDM: string = ''

        /**
         * 账号 0300
         */
        public ZH: string = ''

        /**
         * 账户序号 0340
         */
        public ZHXH: string = ''

        /**
         * 交易金额 0420
         */
        public JYJE: string = ''

        /**
         * 开户机构 0020
         */
        public KHJG: string = ''

        /**
         * 渠道类型 096C
         */
        public QDLX: string = ''

        /**
         * 商户类型 096K
         */
        public SHLX: string = ''

        /**
         * 业务类型 096M
         */
        public YWLX: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new CheckTradeRule()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K039"
            this.MessageData.Fd12 = this.MBJYDM
            this.MessageData.Fd30 = this.ZH
            this.MessageData.Fd34 = this.ZHXH
            this.MessageData.Fd42 = this.JYJE
            this.MessageData.Fd2 = this.KHJG
            this.MessageData.Fd96_C = this.QDLX
            this.MessageData.Fd96_K = this.SHLX
            this.MessageData.Fd96_M = this.YWLX

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }

            return output
        }
    }
    // #endregion
}

/**
 * 创建交易规则检查功能的Vue 3组合式API封装
 */
export function useCheckTradeRule() {
    /**
     * 交易规则检查
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const checkTradeRule = (
        params: {
            MBJYDM: string,  // 目标交易代码
            ZH?: string,     // 账号
            ZHXH?: string,   // 账户序号
            JYJE?: string,   // 交易金额
            KHJG?: string,   // 开户机构
            QDLX?: string,   // 渠道类型
            SHLX?: string,   // 商户类型
            YWLX?: string    // 业务类型
        },
        page: any
    ): CheckTradeRule => {
        const input = new CheckTradeRule.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<CheckTradeRule>(page)
    }

    return {
        checkTradeRule
    }
}
