import { TFInput, TFOutput } from './TFBase'

/**
 * 检查柜员凭证最小号
 * 根据相关要素，检查柜员凭证最小号
 */
export class ChecksTellerSmallestCertificate extends TFOutput {
    // #region Output
    /**
     * 标志位 0730
     * [空格表示没有查询相关数据]第一位[0]介质属性是否存在(0-存在 1-不存在) 第二位[1]是否需要输入卡号(0-否 1是) 第三位[2]卡号是否已经开户(0-否 1-是)第四位[3]是否是次小号码(0-是 1-否)第五位[4]查询最小号是否成功(0-成功 1-失败)第六位[5]卡凭证生成卡号是否成功(0-成功 1-失败)第七位[6]检验位是否正确(0-正确 1-错误)第八位[7]是否是最小号(0-是 1-否)
     */
    public BZW: string = ''

    /**
     * 最小卡号 0370
     * 仅用于开发环境
     */
    public ZXKH: string = ''

    /**
     * 最小凭证号 0580
     * 仅用于开发环境
     */
    public ZXPZH: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 凭证类型 0890
         * 介质代码 、凭证类型 至少输入一个 
         */
        public PZLX: string = ''

        /**
         * 次小号标志 0700
         * 1-校验次小号  其他-校验最小号 
         */
        public CXHBZ: string = ''

        /**
         * 介质代号 1161
         * 介质代码 、凭证类型 至少输入一个 
         */
        public JZDH: string = ''

        /**
         * 卡号 1162
         */
        public KH: string = ''

        /**
         * 凭证号码 1168
         */
        public PZHM: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new ChecksTellerSmallestCertificate()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K053"
            this.MessageData.Fd89 = this.PZLX
            this.MessageData.Fd70 = this.CXHBZ
            this.MessageData.Fd116_1 = this.JZDH
            this.MessageData.Fd116_2 = this.KH
            this.MessageData.Fd116_8 = this.PZHM

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.BZW = this.MessageData.Fd73
            output.ZXKH = this.MessageData.Fd37
            output.ZXPZH = this.MessageData.Fd58

            return output
        }
    }
    // #endregion
}

/**
 * 创建检查柜员凭证最小号功能的Vue 3组合式API封装
 */
export function useChecksTellerSmallestCertificate() {
    /**
     * 检查柜员凭证最小号
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const checksTellerSmallestCertificate = (
        params: {
            PZLX?: string,   // 凭证类型
            CXHBZ?: string,  // 次小号标志
            JZDH?: string,   // 介质代号
            KH?: string,     // 卡号
            PZHM?: string    // 凭证号码
        },
        page: any
    ): ChecksTellerSmallestCertificate => {
        const input = new ChecksTellerSmallestCertificate.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<ChecksTellerSmallestCertificate>(page)
    }

    return {
        checksTellerSmallestCertificate
    }
}
