import { TFInput, TFOutput } from './TFBase'

/**
 * 计算贴现利息
 * 根据输入的要素计算贴现利息
 */
export class CountedInterest extends TFOutput {
    // #region Output
    /**
     * 利息 0410
     */
    public LX: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 票面金额 0400
         */
        public PMJE: string = ''

        /**
         * 交易日期 0440
         */
        public JYRQ: string = ''

        /**
         * 汇票到期日 0450
         */
        public HPDQR: string = ''

        /**
         * 在途天数 0460
         */
        public ZTTS: string = ''

        /**
         * 利率标志 0720
         * 84域输入的利率的类型 D日利率M月利率Y年利率 
         */
        public LLBZ: string = ''

        /**
         * 利率 0840
         */
        public LL: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new CountedInterest()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K007"
            this.MessageData.Fd40 = this.PMJE
            this.MessageData.Fd44 = this.JYRQ
            this.MessageData.Fd45 = this.HPDQR
            this.MessageData.Fd46 = this.ZTTS
            this.MessageData.Fd72 = this.LLBZ
            this.MessageData.Fd84 = this.LL

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.LX = this.DelSpace(this.MessageData.Fd41)

            return output
        }
    }
    // #endregion
}

/**
 * 创建计算贴现利息功能的Vue 3组合式API封装
 */
export function useCountedInterest() {
    /**
     * 计算贴现利息
     * @param params 计算参数
     * @param page 页面对象
     * @returns 计算结果
     */
    const countedInterest = (
        params: {
            PMJE: string,    // 票面金额
            JYRQ: string,    // 交易日期
            HPDQR: string,   // 汇票到期日
            ZTTS: string,    // 在途天数
            LLBZ: string,    // 利率标志
            LL: string       // 利率
        },
        page: any
    ): CountedInterest => {
        const input = new CountedInterest.Input()

        // 设置计算参数
        Object.assign(input, params)

        // 执行计算
        return input.DoAction<CountedInterest>(page)
    }

    return {
        countedInterest
    }
}
