import { TFInput, TFOutput } from './TFBase'

/**
 * 获取利率
 * 根据输入的币种、计息类型获取利率
 */
export class GetRates extends TFOutput {
    // #region Output
    /**
     * 利率 0840
     */
    public LL: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 币种 0210
         */
        public BZ: string = ''

        /**
         * 利率编号 0230
         */
        public LLBH: string = ''

        /**
         * 利率日期 0440
         * 如果为当前挂牌利率可输入当前日期 
         */
        public LLRQ: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new GetRates()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K011"
            this.MessageData.Fd21 = this.BZ
            this.MessageData.Fd23 = this.LLBH
            this.MessageData.Fd44 = this.LLRQ

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.LL = this.DelSpace(this.MessageData.Fd84)

            return output
        }
    }
    // #endregion
}

/**
 * 创建获取利率功能的Vue 3组合式API封装
 */
export function useGetRates() {
    /**
     * 获取利率
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const getRates = (
        params: {
            BZ: string,     // 币种
            LLBH: string,   // 利率编号
            LLRQ: string    // 利率日期
        },
        page: any
    ): GetRates => {
        const input = new GetRates.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<GetRates>(page)
    }

    return {
        getRates
    }
}
