import { TFInput, TFOutput } from './TFBase'

/**
 * 证件号码验证
 * 证件合法性验证
 */
export class IDNumberVerification extends TFOutput {
    // #region Output
    /**
     * 证件号码 0620
     * 15位身份证号转变成18位身份证号
     */
    public ZJHM: string = ''

    /**
     * 验证通过标志 0730
     * 第一位[0]验证是否成功 0.身份证验证失败1.身份证验证成功2.机构代码证验证失败3.机构代码证验证成功
     */
    public YZTGBZ: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 证件类型 0670
         * 1.身份证8.(组织机构)代码证 
         */
        public ZJLX: string = ''

        /**
         * 证件号码 0620
         * 主要验证身份证和组织机构代码证 
         */
        public ZJHM: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new IDNumberVerification()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K020"
            this.MessageData.Fd67 = this.ZJLX
            this.MessageData.Fd62 = this.ZJHM

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.ZJHM = this.MessageData.Fd62
            output.YZTGBZ = this.MessageData.Fd73

            // 是否当前柜员给自己办理业务
            if (this.PageData.SystemSettingsHelper?.Instance?.IsTellerCustomer) {
                const idCarNO = this.PageData.LoginAuthentication?.Instance?.IdCarNO
                if (idCarNO && output.ZJHM.trim() === idCarNO.trim()) {
                    output.IsFailed = true
                    output.FailureCause = "当前柜员不能为自己办理业务！"
                }
            }

            return output
        }
    }
    // #endregion
}

/**
 * 创建证件号码验证功能的Vue 3组合式API封装
 */
export function useIDNumberVerification() {
    /**
     * 证件号码验证
     * @param params 验证参数
     * @param page 页面对象
     * @returns 验证结果
     */
    const verifyIDNumber = (
        params: {
            ZJLX: string,  // 证件类型
            ZJHM: string   // 证件号码
        },
        page: any
    ): IDNumberVerification => {
        const input = new IDNumberVerification.Input()

        // 设置验证参数
        Object.assign(input, params)

        // 执行验证
        return input.DoAction<IDNumberVerification>(page)
    }

    return {
        verifyIDNumber
    }
}
