import { TFInput, TFOutput } from './TFBase'

/**
 * 客户综合签约
 * 客户综合签约
 */
export class MessageComprehensive extends TFOutput {
    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 多电话 0250
         * 多电话  
         */
        public DH: string = ''

        /**
         * 账号 0370
         */
        public ZH: string = ''

        /**
         * 贷方限额 0410
         */
        public DFXE: string = ''

        /**
         * 借方限额 0420
         */
        public JFXE: string = ''

        /**
         * 收费标志 0690
         */
        public SFBZ: string = ''

        /**
         * 账户类型 0710
         */
        public ZHLX: string = ''

        /**
         * 操作方式 0720
         * 0.开通 1.修改 2.注销 
         */
        public CZFS: string = ''

        /**
         * 服务类型 0860
         */
        public FWLX: string = ''

        /**
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new MessageComprehensive()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "8891"
            this.MessageData.Fd25 = this.DH
            this.MessageData.Fd37 = this.ZH
            this.MessageData.Fd41 = this.DFXE
            this.MessageData.Fd42 = this.JFXE
            this.MessageData.Fd69 = this.SFBZ
            this.MessageData.Fd71 = this.ZHLX
            this.MessageData.Fd72 = this.CZFS
            this.MessageData.Fd86 = this.FWLX

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }

            return output
        }
    }
    // #endregion
}

/**
 * 创建客户综合签约功能的Vue 3组合式API封装
 */
export function useMessageComprehensive() {
    /**
     * 执行客户综合签约
     * @param params 签约参数
     * @param page 页面对象
     * @returns 签约结果
     */
    const executeComprehensiveSign = (
        params: {
            DH?: string  // 多电话
            ZH?: string  // 账号
            DFXE?: string  // 贷方限额
            JFXE?: string  // 借方限额
            SFBZ?: string  // 收费标志
            ZHLX?: string  // 账户类型
            CZFS?: string  // 操作方式(0.开通 1.修改 2.注销)
            FWLX?: string  // 服务类型
        },
        page: any
    ): MessageComprehensive => {
        const input = new MessageComprehensive.Input()

        // 设置签约参数
        Object.assign(input, params)

        // 执行签约
        return input.DoAction<MessageComprehensive>(page)
    }

    return {
        executeComprehensiveSign
    }
}
