import { TFInput, TFOutput } from './TFBase'

/**
 * 密码验证
 * 对传入的柜员密码或是凭证密码单或是账号密码进行验证
 */
export class PasswordAuthentication extends TFOutput {
    // #region Output
    /**
     * 凭证密码验证方式 0670
     * 0.密码单1.支付密码器
     */
    public PZMMYZFS: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 账号 0300
         * (null) 
         */
        public ZH: string = ''

        /**
         * 出票日期 0440
         * (null) 
         */
        public CPRQ: string = ''

        /**
         * 凭证号码 0580
         * (null) 
         */
        public PZHM: string = ''

        /**
         * 验证标志 0670
         * 0.账户密码1.柜员密码2.凭证密码3.支付密码器4.凭证密码方式选择 
         */
        public YZBZ: string = ''

        /**
         * 密码 0800
         * (null) 
         */
        public MM: string = ''

        /**
         * 凭证类型 0890
         * (null) 
         */
        public PZLX: string = ''

        /**
         * 柜员号 0920
         * (null) 
         */
        public GYH: string = ''

        /**
         * 票面金额 0400
         */
        public PMJE: string = ''

        /**
         * 证件号码 0620
         */
        public ZJHM: string = ''

        /**
         * 证件类型 0680
         */
        public ZJLX: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new PasswordAuthentication()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K021"
            this.MessageData.Fd30 = this.ZH
            this.MessageData.Fd44 = this.CPRQ
            this.MessageData.Fd58 = this.PZHM
            this.MessageData.Fd67 = this.YZBZ

            // 国密改造
            if (this.PageData.TradeManagerHandle?.TT_SYSCONFIG_GetConfigValueByConfigID("EncrypteGM") === "true") {
                this.MessageData.Fd122_I = this.MM
            } else {
                this.MessageData.Fd80 = this.MM
            }

            this.MessageData.Fd89 = this.PZLX
            this.MessageData.Fd92 = this.GYH
            this.MessageData.Fd40 = this.PMJE
            this.MessageData.Fd62 = this.ZJHM
            this.MessageData.Fd68 = this.ZJLX

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.PZMMYZFS = this.MessageData.Fd67

            return output
        }
    }
    // #endregion
}

/**
 * 创建密码验证功能的Vue 3组合式API封装
 */
export function usePasswordAuthentication() {
    /**
     * 密码验证
     * @param params 验证参数
     * @param page 页面对象
     * @returns 验证结果
     */
    const verifyPassword = (
        params: {
            ZH?: string,    // 账号
            CPRQ?: string,  // 出票日期
            PZHM?: string,  // 凭证号码
            YZBZ: string,   // 验证标志：0.账户密码1.柜员密码2.凭证密码3.支付密码器4.凭证密码方式选择
            MM: string,     // 密码
            PZLX?: string,  // 凭证类型
            GYH?: string,   // 柜员号
            PMJE?: string,  // 票面金额
            ZJHM?: string,  // 证件号码
            ZJLX?: string   // 证件类型
        },
        page: any
    ): PasswordAuthentication => {
        const input = new PasswordAuthentication.Input()

        // 设置验证参数
        Object.assign(input, params)

        // 执行验证
        return input.DoAction<PasswordAuthentication>(page)
    }

    return {
        verifyPassword
    }
}
