import { TFInput, TFOutput } from './TFBase'

/**
 * 客户综合签约
 * 电话签约
 */
export class PhoneComprehensive extends TFOutput {
    // #region Output
    // 无特定输出属性
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 账号 0370
         */
        public ZH: string = ''

        /**
         * 签约标志 0670
         * 0.签约2.解约3.重置密码4.修改密码
         */
        public QYBZ: string = ''

        /**
         * 支取密码 0790
         */
        public ZQMM: string = ''

        /**
         * 电话银行密码 0800
         */
        public DHYHMM: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new PhoneComprehensive()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "9316"
            this.MessageData.Fd37 = this.ZH
            this.MessageData.Fd67 = this.QYBZ
            this.MessageData.Fd79 = this.ZQMM
            this.MessageData.Fd80 = this.DHYHMM

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }

            return output
        }
    }
    // #endregion
}

/**
 * 创建电话签约功能的Vue 3组合式API封装
 */
export function usePhoneComprehensive() {
    /**
     * 电话签约
     * @param params 签约参数
     * @param page 页面对象
     * @returns 签约结果
     */
    const phoneComprehensive = (
        params: {
            ZH: string,     // 账号
            QYBZ: string,   // 签约标志：0.签约2.解约3.重置密码4.修改密码
            ZQMM: string,   // 支取密码
            DHYHMM: string  // 电话银行密码
        },
        page: any
    ): PhoneComprehensive => {
        const input = new PhoneComprehensive.Input()

        // 设置签约参数
        Object.assign(input, params)

        // 执行签约
        return input.DoAction<PhoneComprehensive>(page)
    }

    return {
        phoneComprehensive
    }
}
