import { TFInput, TFOutput } from './TFBase'

/**
 * 指定一级科目下的活期产品
 * 根据一级科目号、介质代码查询产品列表
 */
export class ProductUnderLevelSubjects extends TFOutput {
    // #region Output
    /**
     * 产品列表
     * 文件附件:产品代码|产品描述|
     */
    public CPLB: string = ''

    /**
     * 产品列表
     * 文件附件:产品代码|产品描述|
     */
    public CPLBData: E_CPLB[] = []

    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 币种 0210
         * 必输
         */
        public BZ: string = ''

        /**
         * 产品可以使用的介质代码 0310
         * 可选输入
         */
        public CPKYSYDJZDM: string = ''

        /**
         * 客户类型 0670
         * 0：公用；1：个人；2：公司；3：机构（指政府机关等组织）；4：金融同业；5：内部员工；6金融机构
         */
        public KHLX: string = ''

        /**
         * 业务种类 0300
         * 一级科目号
         */
        public YWZL: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new ProductUnderLevelSubjects()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd21 = this.BZ
            this.MessageData.Fd31 = this.CPKYSYDJZDM
            this.MessageData.Fd67 = this.KHLX
            this.MessageData.Fd128 = "0013"
            this.MessageData.Fd30 = this.YWZL

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.CPLBData = this.AnilyzeFileData<E_CPLB>(this.MessageData.FileData,
                "产品代码|产品描述|",
                (x) => {
                    return {
                        CPDM: x["产品代码"],
                        CPMS: x["产品描述"]
                    }
                })
            output.CPLB = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 产品列表项
 * 文件附件:产品代码|产品描述|
 */
export interface E_CPLB {
    /**
     * 产品代码
     */
    CPDM: string

    /**
     * 产品描述
     */
    CPMS: string
}

/**
 * 创建产品查询功能的Vue 3组合式API封装
 */
export function useProductUnderLevelSubjects() {
    /**
     * 查询指定一级科目下的活期产品
     * @param params 查询参数
     * @param page 页面对象
     * @returns 产品列表结果
     */
    const queryProducts = (
        params: {
            BZ: string,           // 币种
            CPKYSYDJZDM?: string, // 产品可以使用的介质代码
            KHLX: string,         // 客户类型：0：公用；1：个人；2：公司；3：机构；4：金融同业；5：内部员工；6金融机构
            YWZL: string          // 业务种类（一级科目号）
        },
        page: any
    ): ProductUnderLevelSubjects => {
        const input = new ProductUnderLevelSubjects.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<ProductUnderLevelSubjects>(page)
    }

    return {
        queryProducts
    }
}
