import { TFInput, TFOutput } from './TFBase'

/**
 * 按合同号查询抵质押信息结果
 */
export interface CollateralInfoByHTCode {
    /** 业务类型 0220 */
    DKLX: string
    /** 审批未放款金额 1001 */
    SPWFKJE: string
    /** 已关联金额 1002 */
    YGLJE: string
    /** 已开户未销户抵质押贷款金额 1003 */
    YKHWXHDZYDKJE: string
    /** 该合同下的抵质押贷款余额 1004 */
    GHTXDDZYDKYE: string
    /** 是否有该笔合同 0730 (N:没有 Y:有) */
    SFYGBHT: string
}

/**
 * 按合同号查询抵质押信息
 * 根据合同号查询并返回相关的抵质押信息
 */
export class QueryCollateralInformationByHTCode extends TFOutput implements CollateralInfoByHTCode {
    // 输出字段
    public DKLX: string = ''
    public SPWFKJE: string = ''
    public YGLJE: string = ''
    public YKHWXHDZYDKJE: string = ''
    public GHTXDDZYDKYE: string = ''
    public SFYGBHT: string = ''

    // #region Input
    /**
     * 查询抵质押信息的输入参数
     */
    public static Input = class extends TFInput {
        /** 合同号 0860 */
        public HTH: string = ''

        /**
         * 执行抵质押信息查询
         * @returns 查询结果
         */
        public override Raise(): TFOutput {
            const output = new QueryCollateralInformationByHTCode()

            // 初始化交易数据
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)

            // 设置查询参数
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K047"
            this.MessageData.Fd86 = this.HTH

            // 调用服务
            this.PageData.TradeAPIs.CallServer(this.MessageData)

            // 错误处理
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
                return output
            }

            // 设置返回的抵质押信息
            output.DKLX = this.MessageData.Fd22
            output.SPWFKJE = this.MessageData.Fd100_1
            output.YGLJE = this.MessageData.Fd100_2
            output.YKHWXHDZYDKJE = this.MessageData.Fd100_3
            output.GHTXDDZYDKYE = this.MessageData.Fd100_4
            output.SFYGBHT = this.MessageData.Fd73

            return output
        }
    }
    // #endregion
}

/**
 * 创建按合同号查询抵质押信息的Vue 3组合式API封装
 */
export function useQueryCollateralByHTCode() {
    /**
     * 执行按合同号查询抵质押信息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const executeCollateralQuery = (
        params: {
            HTH?: string    // 合同号
        },
        page: any
    ): QueryCollateralInformationByHTCode => {
        const input = new QueryCollateralInformationByHTCode.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryCollateralInformationByHTCode>(page)
    }

    return {
        executeCollateralQuery
    }
}
