import { TFInput, TFOutput } from './TFBase'

/**
 * 客户信息查询结果
 */
export interface CustomerInformation {
    /** 帐户状态 0200 */
    ZHZT: string
    /** 户名 1202 */
    HM: string
    /** 客户号 0280 */
    KHH: string
    /** 有效起始日期 0440 */
    YXQSRQ: string
    /** 有效到期日期 0450 */
    YXDQRQ: string
    /** 指定卡类型卡开户张数 0480 */
    KKHZS: string
    /** 预警次数 0490 */
    YJCS: string
    /** 电话 0610 */
    DH: string
    /** 客户级别 0660 */
    KHJB: string
    /** 客户类型 0670 */
    KHLX: string
    /** 客户当前状态 0680 */
    KHDQZT: string
    /** 收费黑名单类型 0690 */
    SFHMDLX: string
    /** 客户黑名单状态 0700 */
    KHHMDZT: string
    /** 客户级别变更模式 0710 */
    KHJBBGMS: string
    /** 标志 0730 */
    BZ: string
    /** 地址 0810 */
    DZ: string
    /** 收费黑名单备注 0820 */
    SFHMDBZ: string
    /** 单位地址 0830 */
    DWDZ: string
    /** 开销户登记簿中账户状态 0930 */
    KXHDJBZZHZT: string
    /** 证件类型 1164 */
    ZJLX: string
    /** 证件号码 1165 */
    ZJHM: string
    /** 法定代理人名称 0270 */
    FDDLRMC: string
    /** 法定代理人证件号码 0620 */
    FDDLRZJHM: string
    /** 组织机构代码证 0630 */
    ZZJGDMZ: string
    /** 法定代理人证件类型 0720 */
    FDDLRZJLX: string
    /** 企业联系人 1166 */
    QYLXR: string
    /** 传真 1167 */
    CZ: string
    /** 邮编 1168 */
    YB: string
    /** 电子邮箱 0250 */
    DZYX: string
    /** 手机号 0860 */
    SJH: string
    /** 营业执照 0870 */
    YYZZ: string
    /** 客户开立机构 0910 */
    KHKLJG: string
    /** 基本户数量 0500 */
    JBHSL: string
    /** 一般户数量 0510 */
    YBHSL: string
    /** 临时户数量 0550 */
    LSHSL: string
    /** 总开卡数 0360 */
    ZKKS: string
    /** VIP卡数量 103H */
    VIPS: string
    /** 二类账户开户数量 1017 */
    ELZHKHSL: string
    /** 客户信息标志位 1016 */
    MARK: string
}

/**
 * 查询客户信息
 * 根据客户号、账号、证件类型及号码查询并返回客户信息
 */
export class QueryCustomerInformation extends TFOutput implements CustomerInformation {
    // 客户信息字段
    public ZHZT: string = ''
    public HM: string = ''
    public KHH: string = ''
    public YXQSRQ: string = ''
    public YXDQRQ: string = ''
    public KKHZS: string = ''
    public YJCS: string = ''
    public DH: string = ''
    public KHJB: string = ''
    public KHLX: string = ''
    public KHDQZT: string = ''
    public SFHMDLX: string = ''
    public KHHMDZT: string = ''
    public KHJBBGMS: string = ''
    public BZ: string = ''
    public DZ: string = ''
    public SFHMDBZ: string = ''
    public DWDZ: string = ''
    public KXHDJBZZHZT: string = ''
    public ZJLX: string = ''
    public ZJHM: string = ''
    public FDDLRMC: string = ''
    public FDDLRZJHM: string = ''
    public ZZJGDMZ: string = ''
    public FDDLRZJLX: string = ''
    public QYLXR: string = ''
    public CZ: string = ''
    public YB: string = ''
    public DZYX: string = ''
    public SJH: string = ''
    public YYZZ: string = ''
    public KHKLJG: string = ''
    public JBHSL: string = ''
    public YBHSL: string = ''
    public LSHSL: string = ''
    public ZKKS: string = ''
    public VIPS: string = ''
    public ELZHKHSL: string = ''
    public MARK: string = ''

    // #region Input
    /**
     * 查询客户信息的输入参数
     */
    public static Input = class extends TFInput {
        /** 客户名称 0260 */
        public KHMC: string = ''
        /** 客户号 0280 */
        public KHH: string = ''
        /** 账号 0300 */
        public ZH: string = ''
        /** 介质代码 1161 */
        public JZDM: string = ''
        /** 证件类型 1164 */
        public ZJLX: string = ''
        /** 证件号码 1165 */
        public ZJHM: string = ''

        /**
         * 执行客户信息查询
         * @returns 查询结果
         */
        public override Raise(): TFOutput {
            const output = new QueryCustomerInformation()

            // 初始化交易数据
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)

            // 设置查询参数
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K018"
            this.MessageData.Fd26 = this.KHMC
            this.MessageData.Fd28 = this.KHH
            this.MessageData.Fd30 = this.ZH
            this.MessageData.Fd116_1 = this.JZDM
            this.MessageData.Fd116_4 = this.ZJLX
            this.MessageData.Fd116_5 = this.ZJHM

            // 调用服务
            this.PageData.TradeAPIs.CallServer(this.MessageData)

            // 错误处理
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
                return output
            }

            // 设置返回的客户信息
            output.ZHZT = this.MessageData.Fd20
            output.HM = this.MessageData.Fd120_2
            output.KHH = this.MessageData.Fd28
            output.YXQSRQ = this.MessageData.Fd44
            output.YXDQRQ = this.MessageData.Fd45
            output.KKHZS = this.MessageData.Fd48
            output.YJCS = this.MessageData.Fd49
            output.DH = this.MessageData.Fd61
            output.KHJB = this.MessageData.Fd66
            output.KHLX = this.MessageData.Fd67
            output.KHDQZT = this.MessageData.Fd68
            output.SFHMDLX = this.MessageData.Fd69
            output.KHHMDZT = this.MessageData.Fd70
            output.KHJBBGMS = this.MessageData.Fd71
            output.BZ = this.MessageData.Fd73
            output.DZ = this.MessageData.Fd81
            output.SFHMDBZ = this.MessageData.Fd82
            output.DWDZ = this.MessageData.Fd83
            output.KXHDJBZZHZT = this.MessageData.Fd93
            output.ZJLX = this.MessageData.Fd116_4
            output.ZJHM = this.MessageData.Fd116_5
            output.FDDLRMC = this.MessageData.Fd27
            output.FDDLRZJHM = this.MessageData.Fd62
            output.ZZJGDMZ = this.MessageData.Fd63
            output.FDDLRZJLX = this.MessageData.Fd72
            output.QYLXR = this.MessageData.Fd116_6
            output.CZ = this.MessageData.Fd116_7
            output.YB = this.MessageData.Fd116_8
            output.DZYX = this.MessageData.Fd25
            output.SJH = this.MessageData.Fd86
            output.YYZZ = this.MessageData.Fd87
            output.KHKLJG = this.MessageData.Fd91
            output.JBHSL = this.MessageData.Fd50
            output.YBHSL = this.MessageData.Fd51
            output.LSHSL = this.MessageData.Fd55
            output.ZKKS = this.MessageData.Fd36
            output.VIPS = this.MessageData.Fd103_H
            output.ELZHKHSL = this.MessageData.Fd101_7
            output.MARK = this.MessageData.Fd101_6

            return output
        }
    }
    // #endregion
}

/**
 * 创建客户信息查询的Vue 3组合式API封装
 */
export function useQueryCustomerInformation() {
    /**
     * 执行客户信息查询
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const executeCustomerQuery = (
        params: {
            KHMC?: string    // 客户名称
            KHH?: string     // 客户号
            ZH?: string      // 账号
            JZDM?: string    // 介质代码
            ZJLX?: string    // 证件类型
            ZJHM?: string    // 证件号码
        },
        page: any
    ): QueryCustomerInformation => {
        const input = new QueryCustomerInformation.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryCustomerInformation>(page)
    }

    return {
        executeCustomerQuery
    }
}
