import { TFInput, TFOutput } from './TFBase'

/**
 * 错误码同步
 * 错误码同步
 */
export class QueryErrorCodeInfo extends TFOutput {
    // #region Output
    /**
     * 文件
     */
    public WJ: string = ''

    /**
     * 文件数据
     */
    public WJData: E_WJ[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryErrorCodeInfo()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd128 = "0080"

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.WJData = this.AnilyzeFileData<E_WJ>(this.MessageData.FileData,
                "错误码|错误描述|",
                (x) => {
                    return {
                        CWM: x["错误码"],
                        CWMS: x["错误描述"]
                    }
                })
            output.WJ = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 错误码信息
 */
export interface E_WJ {
    /**
     * 错误码
     */
    CWM: string

    /**
     * 错误描述
     */
    CWMS: string
}

/**
 * 创建错误码同步功能的Vue 3组合式API封装
 */
export function useQueryErrorCodeInfo() {
    /**
     * 查询错误码信息
     * @param page 页面对象
     * @returns 错误码信息结果
     */
    const queryErrorCodes = (page: any): QueryErrorCodeInfo => {
        const input = new QueryErrorCodeInfo.Input()

        // 执行查询
        return input.DoAction<QueryErrorCodeInfo>(page)
    }

    return {
        queryErrorCodes
    }
}
