import { TFInput, TFOutput } from './TFBase'

/**
 * 收费黑白名单查询
 * 收费黑白名单查询
 */
export class QueryFeeBlackList extends TFOutput {
    // #region Output
    /**
     * 名单列表
     * 名单范围|交易机构|登记机构|客户类型|客户号|户名|控制类型|控制账号|名单性质|交易日期|流水号|操作柜员|授权人|状态|备注|
     */
    public MDLB: string = ''

    /**
     * 名单列表
     * 名单范围|交易机构|登记机构|客户类型|客户号|户名|控制类型|控制账号|名单性质|交易日期|流水号|操作柜员|授权人|状态|备注|
     */
    public MDLBData: E_MDLB[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 客户号 0280
         * 名单范围为2.指定客户时输入 
         */
        public KHH: string = ''

        /**
         * 账号 0300
         * 名单范围为1.指定账户时输入 
         */
        public ZH: string = ''

        /**
         * 客户类型 0670
         * 1.个人2.对公 
         */
        public KHLX: string = ''

        /**
         * 名单范围 0690
         * 1.指定账户2.指定客户 
         */
        public MDFW: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryFeeBlackList()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd28 = this.KHH
            this.MessageData.Fd30 = this.ZH
            this.MessageData.Fd67 = this.KHLX
            this.MessageData.Fd69 = this.MDFW
            this.MessageData.Fd128 = "0049"

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.MDLBData = this.AnilyzeFileData<E_MDLB>(this.MessageData.FileData,
                "名单范围|交易机构|登记机构|客户类型|客户号|户名|控制类型|控制账号|名单性质|交易日期|流水号|操作柜员|授权人|状态|备注|",
                (x) => {
                    return {
                        MDFW: x["名单范围"],
                        JYJG: x["交易机构"],
                        DJJG: x["登记机构"],
                        KHLX: x["客户类型"],
                        KHH: x["客户号"],
                        HM: x["户名"],
                        KZLX: x["控制类型"],
                        KZZH: x["控制账号"],
                        MDXZ: x["名单性质"],
                        JYRQ: x["交易日期"],
                        LSH: x["流水号"],
                        CZGY: x["操作柜员"],
                        SQR: x["授权人"],
                        ZT: x["状态"],
                        BZ: x["备注"]
                    }
                })
            output.MDLB = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 名单列表项
 * 名单范围|交易机构|登记机构|客户类型|客户号|户名|控制类型|控制账号|名单性质|交易日期|流水号|操作柜员|授权人|状态|备注|
 */
export interface E_MDLB {
    /**
     * 名单范围
     */
    MDFW: string

    /**
     * 交易机构
     */
    JYJG: string

    /**
     * 登记机构
     */
    DJJG: string

    /**
     * 客户类型
     */
    KHLX: string

    /**
     * 客户号
     */
    KHH: string

    /**
     * 户名
     */
    HM: string

    /**
     * 控制类型
     */
    KZLX: string

    /**
     * 控制账号
     */
    KZZH: string

    /**
     * 名单性质
     */
    MDXZ: string

    /**
     * 交易日期
     */
    JYRQ: string

    /**
     * 流水号
     */
    LSH: string

    /**
     * 操作柜员
     */
    CZGY: string

    /**
     * 授权人
     */
    SQR: string

    /**
     * 状态
     */
    ZT: string

    /**
     * 备注
     */
    BZ: string
}

/**
 * 创建收费黑白名单查询功能的Vue 3组合式API封装
 */
export function useQueryFeeBlackList() {
    /**
     * 查询收费黑白名单
     * @param params 查询参数
     * @param page 页面对象
     * @returns 名单查询结果
     */
    const queryFeeBlackList = (
        params: {
            KHH?: string,   // 客户号（名单范围为2.指定客户时输入）
            ZH?: string,    // 账号（名单范围为1.指定账户时输入）
            KHLX: string,   // 客户类型：1.个人2.对公
            MDFW: string    // 名单范围：1.指定账户2.指定客户
        },
        page: any
    ): QueryFeeBlackList => {
        const input = new QueryFeeBlackList.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryFeeBlackList>(page)
    }

    return {
        queryFeeBlackList
    }
}
