import { TFInput, TFOutput } from './TFBase'

/**
 * 收费业务费用编号查询
 * 收费业务费用编号查询
 */
export class QueryFeeNumberList extends TFOutput {
    // #region Output
    /**
     * 收费列表
     * 文件附件:费用编号|费用名| 
     */
    public SFLB: string = ''

    /**
     * 收费列表
     * 文件附件:费用编号|费用名| 
     */
    public SFLBData: E_SFLB[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 一级收费类型 0490
         * 1:结算业务手续费收入 2:工本费费收入 3:代理业务手续费收入 4:顾问及咨询业务收入 5:担保业务手续费收入 6:应付邮寄费 
         */
        public YJSFLX: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryFeeNumberList()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd49 = this.YJSFLX
            this.MessageData.Fd128 = "0041"

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.SFLBData = this.AnilyzeFileData<E_SFLB>(this.MessageData.FileData,
                "费用编号|费用名| ",
                (x) => {
                    return {
                        FYBH: x["费用编号"],
                        FYM: x["费用名"]
                    }
                })
            output.SFLB = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 收费列表项
 * 文件附件:费用编号|费用名| 
 */
export interface E_SFLB {
    /**
     * 费用编号
     */
    FYBH: string

    /**
     * 费用名
     */
    FYM: string
}

/**
 * 创建收费业务费用编号查询功能的Vue 3组合式API封装
 */
export function useQueryFeeNumberList() {
    /**
     * 查询费用编号列表
     * @param params 查询参数
     * @param page 页面对象
     * @returns 费用编号查询结果
     */
    const queryFeeNumbers = (
        params: {
            YJSFLX: string  // 一级收费类型：1:结算业务手续费收入 2:工本费费收入 3:代理业务手续费收入 4:顾问及咨询业务收入 5:担保业务手续费收入 6:应付邮寄费
        },
        page: any
    ): QueryFeeNumberList => {
        const input = new QueryFeeNumberList.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryFeeNumberList>(page)
    }

    return {
        queryFeeNumbers
    }
}
