import { TFInput, TFOutput } from './TFBase'

/**
 * 收费查询
 * 根据交易代码、账号、业务类型等预算收费
 */
export class QueryFeePaymentInfo extends TFOutput {
    // #region Output
    /**
     * 收费列表
     * 第1行：收费方式|收费黑名单标志|黑名单账户；其中,收费方式--共四位：每位0不允许，1允许 第一位：现金 第二位：转账（交易账号） 第三位：输入其他账号 第四位：不收 如1010表示可以收取现金和其他账号，不能转账，不能不收；收费黑名单标志--0：黑名单 1：白名单；第n+1行：|费用描述|应收金额|实收金额(优惠后)；
     */
    public SFLB: string = ''

    /**
     * 收费标志 0120
     * P047:需要收费  0000：不需要收费
     */
    public SFBZ: string = ''

    /**
     * 收费黑白名单标志 1225
     * 0:黑名单 1:白名单
     */
    public SFHBMDBZ: string = ''

    /**
     * 实收总金额 1227
     */
    public SSZJE: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 目标交易代码 0120
         */
        public JYDM: string = ''

        /**
         * 渠道类型 096C
         */
        public QDLX: string = ''

        /**
         * 业务类型 096M
         */
        public YWLX: string = ''

        /**
         * 客户号 096N
         * 没有交易主账号的情况下使用
         */
        public KHH: string = ''

        /**
         * 账号 1221
         * 交易主账号，据此计算优惠等；此账号可以不是付费账号
         */
        public ZH: string = ''

        /**
         * 加急标志 122F
         * 1：加急 0：正常
         */
        public JJBZ: string = ''

        /**
         * 交易发生额 1222
         */
        public JYFSE: string = ''

        /**
         * 客户类型 0710
         * 1-个人  2-对公
         */
        public KHLX: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryFeePaymentInfo()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "9986"
            this.MessageData.Fd12 = this.JYDM
            this.MessageData.Fd96_C = this.QDLX
            this.MessageData.Fd96_M = this.YWLX
            this.MessageData.Fd96_N = this.KHH
            this.MessageData.Fd122_1 = this.ZH
            this.MessageData.Fd122_F = this.JJBZ
            this.MessageData.Fd122_2 = this.JYFSE
            this.MessageData.Fd71 = this.KHLX

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.SFLB = this.MessageData.FileData
            output.SFBZ = this.MessageData.Fd12
            output.SFHBMDBZ = this.MessageData.Fd122_5
            output.SSZJE = this.MessageData.Fd122_7

            return output
        }
    }
    // #endregion
}

/**
 * 创建收费查询功能的Vue 3组合式API封装
 */
export function useQueryFeePaymentInfo() {
    /**
     * 查询费用缴费信息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 费用缴费信息查询结果
     */
    const queryFeePayment = (
        params: {
            JYDM: string,    // 目标交易代码
            QDLX: string,    // 渠道类型
            YWLX: string,    // 业务类型
            KHH?: string,    // 客户号（没有交易主账号的情况下使用）
            ZH: string,      // 账号（交易主账号，据此计算优惠等；此账号可以不是付费账号）
            JJBZ: string,    // 加急标志（1：加急 0：正常）
            JYFSE: string,   // 交易发生额
            KHLX: string     // 客户类型（1-个人 2-对公）
        },
        page: any
    ): QueryFeePaymentInfo => {
        const input = new QueryFeePaymentInfo.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryFeePaymentInfo>(page)
    }

    return {
        queryFeePayment
    }
}
