import { TFInput, TFOutput } from './TFBase'

/**
 * 查询定期存期类型
 * 根据介质代码查询支持的定期产品存期类型
 */
export class QueryFixedDepositDateType extends TFOutput {
    // #region Output
    /**
     * 定期存期类型列表
     * 存期类型|类型名称|
     */
    public DQCQLXLB: string = ''

    /**
     * 定期存期类型列表
     * 存期类型|类型名称|
     */
    public DQCQLXLBData: E_DQCQLXLB[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 介质代码 1161
         */
        public JZDM: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryFixedDepositDateType()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd116_1 = this.JZDM
            this.MessageData.Fd128 = "0028"

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.DQCQLXLBData = this.AnilyzeFileData<E_DQCQLXLB>(this.MessageData.FileData,
                "存期类型|类型名称|",
                (x) => {
                    return {
                        CQLX: x["存期类型"],
                        LXMC: x["类型名称"]
                    }
                })
            output.DQCQLXLB = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 定期存期类型列表项
 * 存期类型|类型名称|
 */
export interface E_DQCQLXLB {
    /**
     * 存期类型
     */
    CQLX: string

    /**
     * 类型名称
     */
    LXMC: string
}

/**
 * 创建查询定期存期类型功能的Vue 3组合式API封装
 */
export function useQueryFixedDepositDateType() {
    /**
     * 查询定期存期类型
     * @param params 查询参数
     * @param page 页面对象
     * @returns 定期存期类型查询结果
     */
    const queryFixedDepositDateTypes = (
        params: {
            JZDM: string  // 介质代码
        },
        page: any
    ): QueryFixedDepositDateType => {
        const input = new QueryFixedDepositDateType.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryFixedDepositDateType>(page)
    }

    return {
        queryFixedDepositDateTypes
    }
}
