import { TFInput, TFOutput } from './TFBase'

/**
 * 根据存款类型、存期查询定期产品信息
 * 根据存款类型、存期查询定期产品信息
 */
export class QueryFixedDepositProduct extends TFOutput {
    // #region Output
    /**
     * 最大开户金额 0390
     */
    public ZDKHJE: string = ''

    /**
     * 利率 1005
     */
    public LL: string = ''

    /**
     * 产品代码 1031
     */
    public CPDM: string = ''

    /**
     * 产品名称 1032
     */
    public CPMC: string = ''

    /**
     * 币种 1033
     */
    public BZ: string = ''

    /**
     * 产品类型 1034
     * 1活期 2定期 9内部
     */
    public CPLX: string = ''

    /**
     * 利率类型（定期） 1035
     * 0：产品利率（挂牌利率）；1：手输利率（开户日利率）
     */
    public LLLXDQ: string = ''

    /**
     * 结算类型(活期) 1035
     * D结算 S非结算
     */
    public JSLXHQ: string = ''

    /**
     * 计息类型 1036
     * 0：不计息；1：利随本清；2：按日计息；3：按月计息；4：按季计息；5：按年计息
     */
    public JXLX: string = ''

    /**
     * 最小开户金额 1037
     */
    public ZXKHJE: string = ''

    /**
     * 自动转存限制标志（定期） 103G
     * Y：允许；N：不允许
     */
    public ZDZCXZBZDQ: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 币种 0210
         * 01 
         */
        public BZ: string = ''

        /**
         * 存期 0640
         * (存期类型 Y：年；M：月；D：日) 例如 3M表示3个月 
         */
        public CQ: string = ''

        /**
         * 定期存款类型（定期） 0670
         * 0：整存整取；1：零存整取；2：整存零取；3：存本取息；4：通知存款；5：协议存款；6：定活两便；7：教育储蓄；A: 利润最大化通知存款 
         */
        public DQCKLXDQ: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryFixedDepositProduct()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K040"
            this.MessageData.Fd21 = this.BZ
            this.MessageData.Fd64 = this.CQ
            this.MessageData.Fd67 = this.DQCKLXDQ

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.ZDKHJE = this.DelSpace(this.MessageData.Fd39)
            output.LL = this.DelSpace(this.MessageData.Fd100_5)
            output.CPDM = this.DelSpace(this.MessageData.Fd103_1)
            output.CPMC = this.DelSpace(this.MessageData.Fd103_2)
            output.BZ = this.DelSpace(this.MessageData.Fd103_3)
            output.CPLX = this.DelSpace(this.MessageData.Fd103_4)
            output.LLLXDQ = this.DelSpace(this.MessageData.Fd103_5)
            output.JSLXHQ = this.DelSpace(this.MessageData.Fd103_5)
            output.JXLX = this.DelSpace(this.MessageData.Fd103_6)
            output.ZXKHJE = this.DelSpace(this.MessageData.Fd103_7)
            output.ZDZCXZBZDQ = this.DelSpace(this.MessageData.Fd103_G)

            return output
        }
    }
    // #endregion
}

/**
 * 创建查询定期产品信息功能的Vue 3组合式API封装
 */
export function useQueryFixedDepositProduct() {
    /**
     * 查询定期产品信息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 定期产品信息查询结果
     */
    const queryFixedDepositProduct = (
        params: {
            BZ: string,       // 币种（如：01）
            CQ: string,       // 存期（存期类型 Y：年；M：月；D：日，例如 3M表示3个月）
            DQCKLXDQ: string  // 定期存款类型（0：整存整取；1：零存整取；2：整存零取；3：存本取息；4：通知存款；5：协议存款；6：定活两便；7：教育储蓄；A: 利润最大化通知存款）
        },
        page: any
    ): QueryFixedDepositProduct => {
        const input = new QueryFixedDepositProduct.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryFixedDepositProduct>(page)
    }

    return {
        queryFixedDepositProduct
    }
}
