import { TFInput, TFOutput } from './TFBase'

/**
 * 受托支付支取额度查询
 * 根据账号查询受托支付支取额度
 */
export class QueryFixedPay extends TFOutput {
    // #region Output
    /**
     * 以文件形式返回支取额度
     * 贷款协议号|授权支付协议|支取金额|自主支取限额|委托支付限额|支付方式|收款账号|
     */
    public YWJXSFHZQED: string = ''

    /**
     * 以文件形式返回支取额度
     * 贷款协议号|授权支付协议|支取金额|自主支取限额|委托支付限额|支付方式|收款账号|
     */
    public YWJXSFHZQEDData: E_YWJXSFHZQED[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 账号 0300
         */
        public ZH: string = ''

        /**
         * 扣划标志 0670
         * 1：扣划 2非扣划 
         */
        public KHBZ: string = ''

        /**
         * 支取标志 0690
         * 1：待支取； 2：已支取 
         */
        public ZQBZ: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryFixedPay()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd30 = this.ZH
            this.MessageData.Fd67 = this.KHBZ
            this.MessageData.Fd69 = this.ZQBZ
            this.MessageData.Fd128 = "0024"

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.YWJXSFHZQEDData = this.AnilyzeFileData<E_YWJXSFHZQED>(this.MessageData.FileData,
                "贷款协议号|授权支付协议|支取金额|自主支取限额|委托支付限额|支付方式|收款账号|",
                (x) => {
                    return {
                        DKXYH: x["贷款协议号"],
                        SQZFXY: x["授权支付协议"],
                        ZQJE: x["支取金额"],
                        ZZZQXE: x["自主支取限额"],
                        WTZFXE: x["委托支付限额"],
                        ZFFS: x["支付方式"],
                        SKZH: x["收款账号"]
                    }
                })
            output.YWJXSFHZQED = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 以文件形式返回支取额度项
 * 贷款协议号|授权支付协议|支取金额|自主支取限额|委托支付限额|支付方式|收款账号|
 */
export interface E_YWJXSFHZQED {
    /**
     * 贷款协议号
     */
    DKXYH: string

    /**
     * 授权支付协议
     */
    SQZFXY: string

    /**
     * 支取金额
     */
    ZQJE: string

    /**
     * 自主支取限额
     */
    ZZZQXE: string

    /**
     * 委托支付限额
     */
    WTZFXE: string

    /**
     * 支付方式
     */
    ZFFS: string

    /**
     * 收款账号
     */
    SKZH: string
}

/**
 * 创建受托支付支取额度查询功能的Vue 3组合式API封装
 */
export function useQueryFixedPay() {
    /**
     * 查询受托支付支取额度
     * @param params 查询参数
     * @param page 页面对象
     * @returns 受托支付支取额度查询结果
     */
    const queryFixedPay = (
        params: {
            ZH: string,    // 账号
            KHBZ: string,  // 扣划标志（1：扣划 2非扣划）
            ZQBZ: string   // 支取标志（1：待支取； 2：已支取）
        },
        page: any
    ): QueryFixedPay => {
        const input = new QueryFixedPay.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryFixedPay>(page)
    }

    return {
        queryFixedPay
    }
}
