import { TFInput, TFOutput } from './TFBase'

/**
 * 查询账户冻结信息
 * 通过账号查询账户冻结信息
 */
export class QueryFreezeAccountInformation extends TFOutput {
    // #region Output
    /**
     * 计划冻结金额 0400
     */
    public JHDJJE: string = ''

    /**
     * 计划冻结起始日期 0440
     */
    public JHDJQSRQ: string = ''

    /**
     * 到期日期 0450
     */
    public DQRQ: string = ''

    /**
     * 止付种类 0650
     * CKZM存款证明 JHKH计划扣划 CZZF错帐止付 CKZF存款止付（拉存款）CDNF卡年费止付 STZF: 受托止付 QTZF:其它
     */
    public ZFZL: string = ''

    /**
     * 冻结/解冻状态 0690
     * 0未解除 1解除
     */
    public DJJDZT: string = ''

    /**
     * 冻结/止付类型 0700
     * 1全部冻结/止付 2只进不出 3部分冻结/止付 4交易冻结
     */
    public DJZFLX: string = ''

    /**
     * 冻结止付标志 0710
     * 1冻结 2止付
     */
    public DJZFBZ: string = ''

    /**
     * 自动解除标志 0720
     * Y是 N否
     */
    public ZDJCBZ: string = ''

    /**
     * 有效计划冻结金额 0410
     */
    public YXJHDJJE: string = ''

    /**
     * 有效累计已扣划金额 0420
     */
    public YXLJYKHJE: string = ''

    /**
     * 法律文书 1135
     */
    public FLWS: string = ''

    /**
     * 标志位 0730
     * [空格表示没有查询相关数据]第一位[0]:该笔冻结是否生效 1未生效 0生效;第二位[1]:该账户是否还存在其他冻结/止付 1存在 0不存在
     */
    public BZW: string = ''

    /**
     * 冻结执法机关 0680
     * 1海关2司法3税务4检察院
     */
    public DJZFJG: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 账号 0300
         */
        public ZH: string = ''

        /**
         * 账户序号 0340
         */
        public ZHXH: string = ''

        /**
         * 冻结序号 0350
         */
        public DJXH: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryFreezeAccountInformation()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K028"
            this.MessageData.Fd30 = this.ZH
            this.MessageData.Fd34 = this.ZHXH
            this.MessageData.Fd35 = this.DJXH

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.JHDJJE = this.DelSpace(this.MessageData.Fd40)
            output.JHDJQSRQ = this.DelSpace(this.MessageData.Fd44)
            output.DQRQ = this.DelSpace(this.MessageData.Fd45)
            output.ZFZL = this.DelSpace(this.MessageData.Fd65)
            output.DJJDZT = this.DelSpace(this.MessageData.Fd69)
            output.DJZFLX = this.DelSpace(this.MessageData.Fd70)
            output.DJZFBZ = this.DelSpace(this.MessageData.Fd71)
            output.ZDJCBZ = this.DelSpace(this.MessageData.Fd72)
            output.YXJHDJJE = this.DelSpace(this.MessageData.Fd41)
            output.YXLJYKHJE = this.DelSpace(this.MessageData.Fd42)
            output.BZW = this.MessageData.Fd73
            output.DJZFJG = this.DelSpace(this.MessageData.Fd68)
            output.FLWS = this.DelSpace(this.MessageData.Fd113_5)

            return output
        }
    }
    // #endregion
}

/**
 * 创建账户冻结信息查询功能的Vue 3组合式API封装
 */
export function useQueryFreezeAccountInformation() {
    /**
     * 查询账户冻结信息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 账户冻结信息查询结果
     */
    const queryFreezeAccountInformation = (
        params: {
            ZH: string,    // 账号
            ZHXH: string,  // 账户序号
            DJXH: string   // 冻结序号
        },
        page: any
    ): QueryFreezeAccountInformation => {
        const input = new QueryFreezeAccountInformation.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryFreezeAccountInformation>(page)
    }

    return {
        queryFreezeAccountInformation
    }
}
