import { TFInput, TFOutput } from './TFBase'

/**
 * 冻结登记簿查询
 * 根据账号、序号查询冻结登记簿
 */
export class QueryFreezeList extends TFOutput {
    // #region Output
    /**
     * 冻结登记簿信息
     * 文件格式：冻结止付序号|冻结止付类型|计划冻结金额|起始日期|解除日期|机构号|操作员|说明|冻结止付标志|止付种类|冻结执法机关|冻结法律文书编号| 
     */
    public DJXX: string = ''

    /**
     * 冻结登记簿信息
     * 文件格式：冻结止付序号|冻结止付类型|计划冻结金额|起始日期|解除日期|机构号|操作员|说明|冻结止付标志|止付种类|冻结执法机关|冻结法律文书编号| 
     */
    public DJXXData: E_DJXX[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 账号 0310
         */
        public ZH: string = ''

        /**
         * 账户序号 0340
         */
        public ZHXH: string = ''

        /**
         * 标志 0660
         * 2:冻结扣划只显示冻结记录 4:止付扣划时只显示止付记录,空值返回全部记录 
         */
        public BZ: string = ''

        /**
         * 状态 0670
         * 0:未解除；1:解除，空值返回所有状态 
         */
        public ZT: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryFreezeList()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd31 = this.ZH
            this.MessageData.Fd34 = this.ZHXH
            this.MessageData.Fd66 = this.BZ
            this.MessageData.Fd128 = "0043"
            this.MessageData.Fd67 = this.ZT

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.DJXXData = this.AnilyzeFileData<E_DJXX>(this.MessageData.FileData,
                "冻结止付序号|冻结止付类型|计划冻结金额|起始日期|解除日期|机构号|操作员|说明|冻结止付标志|止付种类|冻结执法机关|冻结法律文书编号| ",
                (x) => {
                    return {
                        DJZFXH: x["冻结止付序号"],
                        DJZFLX: x["冻结止付类型"],
                        JHDJJE: x["计划冻结金额"],
                        QSRQ: x["起始日期"],
                        JCRQ: x["解除日期"],
                        JGH: x["机构号"],
                        CZY: x["操作员"],
                        SM: x["说明"],
                        DJZFBZ: x["冻结止付标志"],
                        ZFZL: x["止付种类"],
                        DJZFJG: x["冻结执法机关"],
                        DJFLWSBH: x["冻结法律文书编号"]
                    }
                })
            output.DJXX = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 冻结登记簿信息项
 * 文件格式：冻结止付序号|冻结止付类型|计划冻结金额|起始日期|解除日期|机构号|操作员|说明|冻结止付标志|止付种类|冻结执法机关|冻结法律文书编号| 
 */
export interface E_DJXX {
    /**
     * 冻结止付序号
     */
    DJZFXH: string

    /**
     * 冻结止付类型
     */
    DJZFLX: string

    /**
     * 计划冻结金额
     */
    JHDJJE: string

    /**
     * 起始日期
     */
    QSRQ: string

    /**
     * 解除日期
     */
    JCRQ: string

    /**
     * 机构号
     */
    JGH: string

    /**
     * 操作员
     */
    CZY: string

    /**
     * 说明
     */
    SM: string

    /**
     * 冻结止付标志
     */
    DJZFBZ: string

    /**
     * 止付种类
     */
    ZFZL: string

    /**
     * 冻结执法机关
     */
    DJZFJG: string

    /**
     * 冻结法律文书编号
     */
    DJFLWSBH: string
}

/**
 * 创建冻结登记簿查询功能的Vue 3组合式API封装
 */
export function useQueryFreezeList() {
    /**
     * 查询冻结登记簿
     * @param params 查询参数
     * @param page 页面对象
     * @returns 冻结登记簿查询结果
     */
    const queryFreezeList = (
        params: {
            ZH: string,    // 账号
            ZHXH: string,  // 账户序号
            BZ?: string,   // 标志（2:冻结扣划只显示冻结记录 4:止付扣划时只显示止付记录,空值返回全部记录）
            ZT?: string    // 状态（0:未解除；1:解除，空值返回所有状态）
        },
        page: any
    ): QueryFreezeList => {
        const input = new QueryFreezeList.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryFreezeList>(page)
    }

    return {
        queryFreezeList
    }
}
