import { TFInput, TFOutput } from './TFBase'

/**
 * 查询划款协议主账号签约信息
 * 查询划款协议主账号签约信息
 */
export class QueryHKXYMainAccountLinkInfo extends TFOutput {
    // #region Output
    /**
     * 账号关系列表
     * ~主账号|主账号序号|从账号|协议类型|留存金额|透支额度|状态|
     */
    public ZHGXLB: string = ''

    /**
     * 账号关系列表
     * ~主账号|主账号序号|从账号|协议类型|留存金额|透支额度|状态|
     */
    public ZHGXLBData: E_ZHGXLB[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 账号 1021
         * 必输 
         */
        public ZH: string = ''

        /**
         * 协议类型 1031
         */
        public XYLX: string = ''

        /**
         * 交易日期起 0440
         */
        public QSRQ: string = ''

        /**
         * 交易日期止 0450
         */
        public ZZRQ: string = ''

        /**
         * 开户机构 0910
         */
        public KHJG: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryHKXYMainAccountLinkInfo()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd102_1 = this.ZH
            this.MessageData.Fd103_1 = this.XYLX
            this.MessageData.Fd128 = "0054"
            this.MessageData.Fd44 = this.QSRQ
            this.MessageData.Fd45 = this.ZZRQ
            this.MessageData.Fd91 = this.KHJG

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.ZHGXLBData = this.AnilyzeFileData<E_ZHGXLB>(this.MessageData.FileData,
                "主账号|主账号序号|从账号|协议类型|留存金额|透支额度|状态|",
                (x) => {
                    return {
                        ZZH: x["主账号"],
                        ZZHXH: x["主账号序号"],
                        CZH: x["从账号"],
                        XYLX: x["协议类型"],
                        LCJE: x["留存金额"],
                        TZED: x["透支额度"],
                        ZT: x["状态"]
                    }
                })
            output.ZHGXLB = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 账号关系列表项
 * ~主账号|主账号序号|从账号|协议类型|留存金额|透支额度|状态|
 */
export interface E_ZHGXLB {
    /**
     * 主账号
     */
    ZZH: string

    /**
     * 主账号序号
     */
    ZZHXH: string

    /**
     * 从账号
     */
    CZH: string

    /**
     * 协议类型
     */
    XYLX: string

    /**
     * 留存金额
     */
    LCJE: string

    /**
     * 透支额度
     */
    TZED: string

    /**
     * 状态
     */
    ZT: string
}

/**
 * 创建划款协议主账号签约信息查询功能的Vue 3组合式API封装
 */
export function useQueryHKXYMainAccountLinkInfo() {
    /**
     * 查询划款协议主账号签约信息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 划款协议主账号签约信息查询结果
     */
    const queryHKXYMainAccountLinkInfo = (
        params: {
            ZH: string,    // 账号（必输）
            XYLX?: string, // 协议类型
            QSRQ?: string, // 交易日期起
            ZZRQ?: string, // 交易日期止
            KHJG?: string  // 开户机构
        },
        page: any
    ): QueryHKXYMainAccountLinkInfo => {
        const input = new QueryHKXYMainAccountLinkInfo.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryHKXYMainAccountLinkInfo>(page)
    }

    return {
        queryHKXYMainAccountLinkInfo
    }
}
