import { TFInput, TFOutput } from './TFBase'

/**
 * 现金付出/接收调剂记录查询根据新旧卡号和换证日期查询换证登记簿
 * 根据新旧卡号和换证日期查询换证登记簿
 */
export class QueryHZDJB extends TFOutput {
    // #region Output
    /**
     * 文件
     * 更换前账号|凭证号码|更换后账号|新凭证号码|介质代码|换证日期|操作员|换证原因|
     */
    public WJ: string = ''

    /**
     * 文件
     * 更换前账号|凭证号码|更换后账号|新凭证号码|介质代码|换证日期|操作员|换证原因|
     */
    public WJData: E_WJ[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 更换前账号 0300
         */
        public GHQZH: string = ''

        /**
         * 更换后账号 0310
         */
        public GHHZH: string = ''

        /**
         * 更换日期起 0440
         */
        public GHRQQ: string = ''

        /**
         * 更换日期止 0450
         */
        public GHRQZ: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryHZDJB()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd30 = this.GHQZH
            this.MessageData.Fd31 = this.GHHZH
            this.MessageData.Fd44 = this.GHRQQ
            this.MessageData.Fd45 = this.GHRQZ
            this.MessageData.Fd128 = "0086"

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.WJData = this.AnilyzeFileData<E_WJ>(this.MessageData.FileData,
                "更换前账号|凭证号码|更换后账号|新凭证号码|介质代码|换证日期|操作员|换证原因|",
                (x) => {
                    return {
                        GHQZH: x["更换前账号"],
                        PZHM: x["凭证号码"],
                        GHHZH: x["更换后账号"],
                        XPZHM: x["新凭证号码"],
                        JZDM: x["介质代码"],
                        HZRQ: x["换证日期"],
                        CZY: x["操作员"],
                        HZYY: x["换证原因"]
                    }
                })
            output.WJ = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 文件数据项接口
 * 更换前账号|凭证号码|更换后账号|新凭证号码|介质代码|换证日期|操作员|换证原因|
 */
export interface E_WJ {
    /**
     * 更换前账号
     */
    GHQZH: string

    /**
     * 凭证号码
     */
    PZHM: string

    /**
     * 更换后账号
     */
    GHHZH: string

    /**
     * 新凭证号码
     */
    XPZHM: string

    /**
     * 介质代码
     */
    JZDM: string

    /**
     * 换证日期
     */
    HZRQ: string

    /**
     * 操作员
     */
    CZY: string

    /**
     * 换证原因
     */
    HZYY: string
}

/**
 * 创建换证登记簿查询功能的Vue 3组合式API封装
 */
export function useQueryHZDJB() {
    /**
     * 根据新旧卡号和换证日期查询换证登记簿
     * @param params 查询参数
     * @param page 页面对象
     * @returns 换证登记簿查询结果
     */
    const queryHZDJB = (
        params: {
            GHQZH?: string, // 更换前账号
            GHHZH?: string, // 更换后账号
            GHRQQ?: string, // 更换日期起
            GHRQZ?: string  // 更换日期止
        },
        page: any
    ): QueryHZDJB => {
        const input = new QueryHZDJB.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryHZDJB>(page)
    }

    return {
        queryHZDJB
    }
}
