import { TFInput, TFOutput } from './TFBase'

/**
 * 根据户名、证件、状态查询分户信息
 * 根据户名、证件、状态查询分户信息
 */
export class QueryIndividualInfo extends TFOutput {
    // #region Output
    /**
     * 内容列表
     * 存款：账号|账户序号|户名|余额|开户机构|产品名称|开户日期|账户类型 
     * 内部：账号|户名|产品名称|余额|账户类型 
     * 贷款：账号|序号|户名|产品名称|余额|账户类型
     */
    public NRLB: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 户名 0250
         */
        public HM: string = ''

        /**
         * 证件号 0620
         */
        public ZJH: string = ''

        /**
         * 证件类型 0660
         */
        public ZJLX: string = ''

        /**
         * 科目号 0640
         * 按科目查询时输入
         */
        public KMH: string = ''

        /**
         * 账户状态 0670
         */
        public ZHZT: string = ''

        /**
         * 查询标志 0690
         * 1存款2内部3贷款
         */
        public CXBZ: string = ''

        /**
         * 开户机构 0910
         */
        public KHJG: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryIndividualInfo()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd25 = this.HM
            this.MessageData.Fd62 = this.ZJH
            this.MessageData.Fd66 = this.ZJLX
            this.MessageData.Fd64 = this.KMH
            this.MessageData.Fd67 = this.ZHZT
            this.MessageData.Fd69 = this.CXBZ
            this.MessageData.Fd128 = "0071"
            this.MessageData.Fd91 = this.KHJG

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.NRLB = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 创建个人信息查询功能的Vue 3组合式API封装
 */
export function useQueryIndividualInfo() {
    /**
     * 根据户名、证件、状态查询分户信息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 分户信息查询结果
     */
    const queryIndividualInfo = (
        params: {
            HM?: string,    // 户名
            ZJH?: string,   // 证件号
            ZJLX?: string,  // 证件类型
            KMH?: string,   // 科目号（按科目查询时输入）
            ZHZT?: string,  // 账户状态
            CXBZ?: string,  // 查询标志（1存款2内部3贷款）
            KHJG?: string   // 开户机构
        },
        page: any
    ): QueryIndividualInfo => {
        const input = new QueryIndividualInfo.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryIndividualInfo>(page)
    }

    return {
        queryIndividualInfo
    }
}
