import { TFInput, TFOutput } from './TFBase'

/**
 * 综合授信卡信息查询
 * 通过授信卡号查询授信信息
 */
export class QueryIntegratedCreditCard extends TFOutput {
    // #region Output
    /**
     * 客户号 0280
     */
    public KHH: string = ''

    /**
     * 第一还款账号 0300
     */
    public DYHKZH: string = ''

    /**
     * 第二还款账号 0310
     */
    public DEHKZH: string = ''

    /**
     * 第三还款账号 0320
     */
    public DSHKZH: string = ''

    /**
     * 签约卡号 0370
     */
    public QYKH: string = ''

    /**
     * 贷款期限 0500
     */
    public DKQX: string = ''

    /**
     * POS免息期 0510
     */
    public POSMXQ: string = ''

    /**
     * 证件号 0620
     */
    public ZJH: string = ''

    /**
     * 签约状态 0660
     * 0正常签约1冻结2终止3解约
     */
    public QYZT: string = ''

    /**
     * 证件类型 0670
     * 1.身份证 2.户口簿 3.护照 6.士兵证 7.港澳居民往来内地通行证 
     * 8：企业代码证；9：组织机构号；A营业执照；B：经营许可证
     * C: 事业法人证书 F.外国人永久居留身份证 G.警官证 H.其他证件 
     * I.台湾同胞来往内地通行证 J.军官证
     */
    public ZJLX: string = ''

    /**
     * 标志位 0730
     * [空格表示没有查询相关数据]标志位:
     * [0]输入合同号是否正确/存在
     * [1]验密是否通过
     * [0]输入合同号是否正确/存在(0.是1.否)是否已关联贷款(0.是1.否)
     * [3]是否有该笔授信记录(0 有  1没有)
     */
    public BZW: string = ''

    /**
     * 逾期利率比 0840
     */
    public YQLLB: string = ''

    /**
     * 罚息利率比 0850
     */
    public FXLLB: string = ''

    /**
     * 复息标志 0930
     * Y是N不是
     */
    public FXBZ: string = ''

    /**
     * 客户名称 0961
     */
    public KHMC: string = ''

    /**
     * 正常利率比 0970
     */
    public ZCLLB: string = ''

    /**
     * 最小放款金额 1001
     */
    public ZXFKJE: string = ''

    /**
     * 授信额度 1002
     */
    public SXED: string = ''

    /**
     * 剩余授信额度 1003
     */
    public SYSXED: string = ''

    /**
     * 产品名称 101F
     */
    public CPMC: string = ''

    /**
     * 计息方式 1036
     * 0：不计息；1：利随本清
     */
    public JXFS: string = ''

    /**
     * 还款方式 103C
     * 1：利随本清；2：按期还息；3：等额本息；4：等本本息；
     * 6：等额递增；7，等额递减；8等比递增；9：等比递减；
     * A：等额气球贷；B：等额上周供
     */
    public HKFS: string = ''

    /**
     * 起始日期 1053
     */
    public QSRQ: string = ''

    /**
     * 到期日期 1054
     */
    public DQRQ: string = ''

    /**
     * 授信年度 109E
     */
    public SXND: string = ''

    /**
     * 授信到期日 1122
     * 授信到期日与前边的到期日期相同
     */
    public SXDQR: string = ''

    /**
     * 违约利率 1123
     */
    public WYLL: string = ''

    /**
     * 逾期利率 1124
     */
    public YQLL: string = ''

    /**
     * 主副卡标志 115A
     * 主副卡卡标志1：主卡 2：附卡3：E卡通.默认为1
     */
    public ZFKBZ: string = ''

    /**
     * 是否允许POS放款 1215
     * 0允许1不允许
     */
    public SFYXPOSFK: string = ''

    /**
     * 合同号 0740
     */
    public HTH: string = ''

    /**
     * 合同利率 1005
     */
    public HTLL: string = ''

    /**
     * 贷款到期日期 0450
     */
    public DKDQRQ: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 签约卡号 0370
         */
        public QYKH: string = ''

        /**
         * 卡密码 0790
         */
        public KMM: string = ''

        /**
         * 合同号 0740
         */
        public HTH: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryIntegratedCreditCard()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K013"
            this.MessageData.Fd37 = this.QYKH
            this.MessageData.Fd79 = this.KMM
            this.MessageData.Fd74 = this.HTH

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.KHH = this.MessageData.Fd28
            output.DYHKZH = this.MessageData.Fd30
            output.DEHKZH = this.MessageData.Fd31
            output.DSHKZH = this.MessageData.Fd32
            output.QYKH = this.MessageData.Fd37
            output.DKQX = this.MessageData.Fd50
            output.POSMXQ = this.MessageData.Fd51
            output.ZJH = this.MessageData.Fd62
            output.QYZT = this.MessageData.Fd66
            output.ZJLX = this.MessageData.Fd67
            output.BZW = this.MessageData.Fd73
            output.YQLLB = this.MessageData.Fd84
            output.FXLLB = this.MessageData.Fd85
            output.FXBZ = this.MessageData.Fd93
            output.KHMC = this.MessageData.Fd96_1
            output.ZCLLB = this.MessageData.Fd97
            output.ZXFKJE = this.MessageData.Fd100_1
            output.SXED = this.MessageData.Fd100_2
            output.SYSXED = this.MessageData.Fd100_3
            output.CPMC = this.MessageData.Fd101_F
            output.JXFS = this.MessageData.Fd103_6
            output.HKFS = this.MessageData.Fd103_C
            output.QSRQ = this.MessageData.Fd105_3
            output.DQRQ = this.MessageData.Fd105_4
            output.SXND = this.MessageData.Fd109_E
            output.SXDQR = this.MessageData.Fd112_2
            output.WYLL = this.MessageData.Fd112_3
            output.YQLL = this.MessageData.Fd112_4
            output.ZFKBZ = this.MessageData.Fd115_A
            output.SFYXPOSFK = this.MessageData.Fd121_5
            output.HTH = this.MessageData.Fd74
            output.HTLL = this.MessageData.Fd100_5
            output.DKDQRQ = this.MessageData.Fd45

            return output
        }
    }
    // #endregion
}

/**
 * 创建综合授信卡信息查询功能的Vue 3组合式API封装
 */
export function useQueryIntegratedCreditCard() {
    /**
     * 通过授信卡号查询授信信息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 综合授信卡信息查询结果
     */
    const queryIntegratedCreditCard = (
        params: {
            QYKH?: string, // 签约卡号
            KMM?: string,  // 卡密码
            HTH?: string   // 合同号
        },
        page: any
    ): QueryIntegratedCreditCard => {
        const input = new QueryIntegratedCreditCard.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryIntegratedCreditCard>(page)
    }

    return {
        queryIntegratedCreditCard
    }
}
