import { TFInput, TFOutput } from './TFBase'

/**
 * 假币没收多笔查询(文件)
 * 查询没收假币的详细信息
 */
export class QueryJBMSDBJL extends TFOutput {
    // #region Output
    /**
     * 文件
     * 登记日期|交易机构|登记柜员|收缴凭证号|收缴假币序号|客户姓名|证件类型|证件号码|上缴编号|上缴日期|币种|版别|劵别|没收张数|冲销张数|制假类型|冠字号码|状态|接收日期|接收机构|接收柜员|复核柜员|现金管理员|
     */
    public WJ: string = ''

    /**
     * 文件
     * 登记日期|交易机构|登记柜员|收缴凭证号|收缴假币序号|客户姓名|证件类型|证件号码|上缴编号|上缴日期|币种|版别|劵别|没收张数|冲销张数|制假类型|冠字号码|状态|接收日期|接收机构|接收柜员|复核柜员|现金管理员|
     */
    public WJData: E_WJ[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 起始日期 0440
         */
        public QSRQ: string = ''

        /**
         * 终止日期 0450
         */
        public ZZRQ: string = ''

        /**
         * 接收机构 0640
         */
        public JSJG: string = ''

        /**
         * 制假方式 0680
         * 0伪造1变造 
         */
        public ZJFS: string = ''

        /**
         * 状态 0690
         * 0已登记未上缴1已上缴未接收2已接收3已出库 
         */
        public ZT: string = ''

        /**
         * 接收柜员 0730
         */
        public JSGY: string = ''

        /**
         * 登记机构 0910
         */
        public DJJG: string = ''

        /**
         * 登记柜员 0920
         */
        public DJGY: string = ''

        /**
         * 上缴编号 0300
         */
        public SJBH: string = ''

        /**
         * 没收证编号 0620
         */
        public MSZBH: string = ''

        /**
         * 现金管理员 0650
         */
        public XJGLY: string = ''

        /**
         * 券别 0890
         */
        public QB: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryJBMSDBJL()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd44 = this.QSRQ
            this.MessageData.Fd45 = this.ZZRQ
            this.MessageData.Fd64 = this.JSJG
            this.MessageData.Fd68 = this.ZJFS
            this.MessageData.Fd69 = this.ZT
            this.MessageData.Fd73 = this.JSGY
            this.MessageData.Fd91 = this.DJJG
            this.MessageData.Fd92 = this.DJGY
            this.MessageData.Fd128 = "0082"
            this.MessageData.Fd30 = this.SJBH
            this.MessageData.Fd62 = this.MSZBH
            this.MessageData.Fd65 = this.XJGLY
            this.MessageData.Fd89 = this.QB

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.WJData = this.AnilyzeFileData<E_WJ>(this.MessageData.FileData,
                "登记日期|交易机构|登记柜员|收缴凭证号|收缴假币序号|客户姓名|证件类型|证件号码|上缴编号|上缴日期|币种|版别|劵别|没收张数|冲销张数|制假类型|冠字号码|状态|接收日期|接收机构|接收柜员|复核柜员|现金管理员|",
                (x) => {
                    return {
                        DJRQ: x["登记日期"],
                        JYJG: x["交易机构"],
                        DJGY: x["登记柜员"],
                        SJPZH: x["收缴凭证号"],
                        SJJBXH: x["收缴假币序号"],
                        KHXM: x["客户姓名"],
                        ZJLX: x["证件类型"],
                        ZJHM: x["证件号码"],
                        SJBH: x["上缴编号"],
                        SJRQ: x["上缴日期"],
                        BZ: x["币种"],
                        BB: x["版别"],
                        B: x["劵别"],
                        MSZS: x["没收张数"],
                        CXZS: x["冲销张数"],
                        ZJLX_1: x["制假类型"],
                        GZHM: x["冠字号码"],
                        ZT: x["状态"],
                        JSRQ: x["接收日期"],
                        JSJG: x["接收机构"],
                        JSGY: x["接收柜员"],
                        FHGY: x["复核柜员"],
                        XJGLY: x["现金管理员"]
                    }
                })
            output.WJ = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 文件数据项接口
 * 登记日期|交易机构|登记柜员|收缴凭证号|收缴假币序号|客户姓名|证件类型|证件号码|上缴编号|上缴日期|币种|版别|劵别|没收张数|冲销张数|制假类型|冠字号码|状态|接收日期|接收机构|接收柜员|复核柜员|现金管理员|
 */
export interface E_WJ {
    /**
     * 登记日期
     */
    DJRQ: string

    /**
     * 交易机构
     */
    JYJG: string

    /**
     * 登记柜员
     */
    DJGY: string

    /**
     * 收缴凭证号
     */
    SJPZH: string

    /**
     * 收缴假币序号
     */
    SJJBXH: string

    /**
     * 客户姓名
     */
    KHXM: string

    /**
     * 证件类型
     */
    ZJLX: string

    /**
     * 证件号码
     */
    ZJHM: string

    /**
     * 上缴编号
     */
    SJBH: string

    /**
     * 上缴日期
     */
    SJRQ: string

    /**
     * 币种
     */
    BZ: string

    /**
     * 版别
     */
    BB: string

    /**
     * 劵别
     */
    B: string

    /**
     * 没收张数
     */
    MSZS: string

    /**
     * 冲销张数
     */
    CXZS: string

    /**
     * 制假类型
     */
    ZJLX_1: string

    /**
     * 冠字号码
     */
    GZHM: string

    /**
     * 状态
     */
    ZT: string

    /**
     * 接收日期
     */
    JSRQ: string

    /**
     * 接收机构
     */
    JSJG: string

    /**
     * 接收柜员
     */
    JSGY: string

    /**
     * 复核柜员
     */
    FHGY: string

    /**
     * 现金管理员
     */
    XJGLY: string
}

/**
 * 创建假币没收多笔查询功能的Vue 3组合式API封装
 */
export function useQueryJBMSDBJL() {
    /**
     * 查询没收假币的详细信息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 假币没收多笔查询结果
     */
    const queryJBMSDBJL = (
        params: {
            QSRQ?: string,  // 起始日期
            ZZRQ?: string,  // 终止日期
            JSJG?: string,  // 接收机构
            ZJFS?: string,  // 制假方式 0伪造1变造
            ZT?: string,    // 状态 0已登记未上缴1已上缴未接收2已接收3已出库
            JSGY?: string,  // 接收柜员
            DJJG?: string,  // 登记机构
            DJGY?: string,  // 登记柜员
            SJBH?: string,  // 上缴编号
            MSZBH?: string, // 没收证编号
            XJGLY?: string, // 现金管理员
            QB?: string     // 券别
        },
        page: any
    ): QueryJBMSDBJL => {
        const input = new QueryJBMSDBJL.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryJBMSDBJL>(page)
    }

    return {
        queryJBMSDBJL
    }
}
