import { TFInput, TFOutput } from './TFBase'

/**
 * 查询假币收缴信息
 * 通过收缴凭证编号查询假币收缴信息
 */
export class QueryJBSJXX extends TFOutput {
    // #region Output
    /**
     * 收缴编号使用标志 0670
     * Y-收缴凭证编号已存在 N-未使用
     */
    public SJBHSYBZ: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 收缴凭证编号 0380
         */
        public SJPZBH: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryJBSJXX()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K070"
            this.MessageData.Fd38 = this.SJPZBH

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.SJBHSYBZ = this.MessageData.Fd67

            return output
        }
    }
    // #endregion
}

/**
 * 创建假币收缴信息查询功能的Vue 3组合式API封装
 */
export function useQueryJBSJXX() {
    /**
     * 通过收缴凭证编号查询假币收缴信息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 假币收缴信息查询结果
     */
    const queryJBSJXX = (
        params: {
            SJPZBH?: string  // 收缴凭证编号
        },
        page: any
    ): QueryJBSJXX => {
        const input = new QueryJBSJXX.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryJBSJXX>(page)
    }

    return {
        queryJBSJXX
    }
}
