import { TFInput, TFOutput } from './TFBase'

/**
 * 机构信用代码证查询(文件)
 * 通过账号或机构信用代码证查询账户信息
 */
export class QueryJGXYDMZ extends TFOutput {
    // #region Output
    /**
     * 文件
     * 账号|账户序号|客户名称|账户状态|凭证类型|凭证号|证件类型|证件号|
     */
    public WJ: string = ''

    /**
     * 文件
     * 账号|账户序号|客户名称|账户状态|凭证类型|凭证号|证件类型|证件号|
     */
    public WJData: E_WJ[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 账号 0300
         */
        public ZH: string = ''

        /**
         * 机构信用代码证号码 0620
         */
        public DMZH: string = ''

        /**
         * 账户状态 0670
         * 1正常0开户待确认3挂失结清4开户更正5临时销户*销户#计息结束6久悬 
         */
        public ZHZT: string = ''

        /**
         * 开户机构 0910
         */
        public KHJG: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryJGXYDMZ()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd30 = this.ZH
            this.MessageData.Fd62 = this.DMZH
            this.MessageData.Fd67 = this.ZHZT
            this.MessageData.Fd91 = this.KHJG
            this.MessageData.Fd128 = "0094"

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.WJData = this.AnilyzeFileData<E_WJ>(this.MessageData.FileData,
                "账号|账户序号|客户名称|账户状态|凭证类型|凭证号|证件类型|证件号|",
                (x) => {
                    return {
                        ZH: x["账号"],
                        ZHXH: x["账户序号"],
                        KHMC: x["客户名称"],
                        ZHZT: x["账户状态"],
                        PZLX: x["凭证类型"],
                        PZH: x["凭证号"],
                        ZJLX: x["证件类型"],
                        ZJH: x["证件号"]
                    }
                })
            output.WJ = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 文件数据项接口
 * 账号|账户序号|客户名称|账户状态|凭证类型|凭证号|证件类型|证件号|
 */
export interface E_WJ {
    /**
     * 账号
     */
    ZH: string

    /**
     * 账户序号
     */
    ZHXH: string

    /**
     * 客户名称
     */
    KHMC: string

    /**
     * 账户状态
     */
    ZHZT: string

    /**
     * 凭证类型
     */
    PZLX: string

    /**
     * 凭证号
     */
    PZH: string

    /**
     * 证件类型
     */
    ZJLX: string

    /**
     * 证件号
     */
    ZJH: string
}

/**
 * 创建机构信用代码证查询功能的Vue 3组合式API封装
 */
export function useQueryJGXYDMZ() {
    /**
     * 通过账号或机构信用代码证查询账户信息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 机构信用代码证查询结果
     */
    const queryJGXYDMZ = (
        params: {
            ZH?: string,    // 账号
            DMZH?: string,  // 机构信用代码证号码
            ZHZT?: string,  // 账户状态 1正常0开户待确认3挂失结清4开户更正5临时销户*销户#计息结束6久悬
            KHJG?: string   // 开户机构
        },
        page: any
    ): QueryJGXYDMZ => {
        const input = new QueryJGXYDMZ.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryJGXYDMZ>(page)
    }

    return {
        queryJGXYDMZ
    }
}
