import { TFInput, TFOutput } from './TFBase'

/**
 * 查询职业类型
 * 根据介质代码查询支持的定期产品存期类型
 */
export class QueryJobTypeList extends TFOutput {
    // #region Output
    /**
     * 职业类型列表
     * 职业类型|职业名称|
     */
    public ZYLB: string = ''

    /**
     * 职业类型列表
     * 职业类型|职业名称|
     */
    public ZYLBData: E_ZYLB[] = []

    /**
     * 职业
     * 一级职业编码
     */
    public ZYBM_1: string = ''

    /**
     * 职业
     * 二级职业编码
     */
    public ZYBM_2: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 查询类型 0670
         */
        public CXLX: string = ''

        /**
         * 职业编码 1264
         */
        public ZYBM: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryJobTypeList()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            //this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K121"
            this.MessageData.Fd67 = this.CXLX
            this.MessageData.Fd126_4 = this.ZYBM

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.ZYLBData = this.AnilyzeFileData<E_ZYLB>(this.MessageData.FileData,
                "职业类型|职业名称|",
                (x) => {
                    return {
                        ZYLX: x["职业类型"],
                        ZYMC: x["职业名称"]
                    }
                })
            output.ZYLB = this.MessageData.FileData
            output.ZYBM_1 = this.MessageData.Fd126_5
            output.ZYBM_2 = this.MessageData.Fd128

            return output
        }
    }
    // #endregion
}

/**
 * 职业类型列表数据项接口
 * 职业类型|职业名称|
 */
export interface E_ZYLB {
    /**
     * 职业类型
     */
    ZYLX: string

    /**
     * 职业名称
     */
    ZYMC: string
}

/**
 * 创建职业类型查询功能的Vue 3组合式API封装
 */
export function useQueryJobTypeList() {
    /**
     * 查询职业类型列表
     * @param params 查询参数
     * @param page 页面对象
     * @returns 职业类型查询结果
     */
    const queryJobTypeList = (
        params: {
            CXLX?: string,  // 查询类型
            ZYBM?: string   // 职业编码
        },
        page: any
    ): QueryJobTypeList => {
        const input = new QueryJobTypeList.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryJobTypeList>(page)
    }

    return {
        queryJobTypeList
    }
}
