import { TFInput, TFOutput } from './TFBase'

/**
 * 客户存款量查询
 * 根据证件类型证件号码查询客户存款量
 */
export class QueryKHCKL extends TFOutput {
    // #region Output
    /**
     * 文件
     * 客户号|产品信息|产品累计额|
     */
    public WJ: string = ''

    /**
     * 文件
     * 客户号|产品信息|产品累计额|
     */
    public WJData: E_WJ[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 证件号码 0620
         */
        public ZJHM: string = ''

        /**
         * 证件类型 0660
         */
        public ZJLX: string = ''

        /**
         * 查询方式 0670
         * 1.按产品查询2.按定活期查询
         */
        public CXFS: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryKHCKL()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd62 = this.ZJHM
            this.MessageData.Fd66 = this.ZJLX
            this.MessageData.Fd67 = this.CXFS
            this.MessageData.Fd128 = "0106"

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.WJData = this.AnilyzeFileData<E_WJ>(this.MessageData.FileData,
                "客户号|产品信息|产品累计额|",
                (x) => {
                    return {
                        KHH: x["客户号"],
                        CPXX: x["产品信息"],
                        CPLJE: x["产品累计额"]
                    }
                })
            output.WJ = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 文件数据项接口
 * 客户号|产品信息|产品累计额|
 */
export interface E_WJ {
    /**
     * 客户号
     */
    KHH: string

    /**
     * 产品信息
     */
    CPXX: string

    /**
     * 产品累计额
     */
    CPLJE: string
}

/**
 * 创建客户存款量查询功能的Vue 3组合式API封装
 */
export function useQueryKHCKL() {
    /**
     * 根据证件类型证件号码查询客户存款量
     * @param params 查询参数
     * @param page 页面对象
     * @returns 客户存款量查询结果
     */
    const queryKHCKL = (
        params: {
            ZJHM?: string,  // 证件号码
            ZJLX?: string,  // 证件类型
            CXFS?: string   // 查询方式 1.按产品查询2.按定活期查询
        },
        page: any
    ): QueryKHCKL => {
        const input = new QueryKHCKL.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryKHCKL>(page)
    }

    return {
        queryKHCKL
    }
}
