import { TFInput, TFOutput } from './TFBase'

/**
 * 查询卡折一体信息(文件)
 * 通过卡号或存折号查询详细信息
 */
export class QueryKZYTXX extends TFOutput {
    // #region Output
    /**
     * 文件
     * 卡号|账户序号|姓名|余额|账户状态|存折账号|账户序号|名称|余额|账户状态|
     */
    public WJ: string = ''

    /**
     * 文件
     * 卡号|账户序号|姓名|余额|账户状态|存折账号|账户序号|名称|余额|账户状态|
     */
    public WJData: E_WJ[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 卡号 0300
         */
        public KH: string = ''

        /**
         * 卡折账号 0310
         */
        public KZZH: string = ''

        /**
         * 账户状态 0670
         * 1正常0开户待确认3挂失结清4开户更正5临时销户*销户#计息结束6久悬 
         */
        public ZHZT: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryKZYTXX()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd30 = this.KH
            this.MessageData.Fd31 = this.KZZH
            this.MessageData.Fd128 = "0093"
            this.MessageData.Fd67 = this.ZHZT

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.WJData = this.AnilyzeFileData<E_WJ>(this.MessageData.FileData,
                "卡号|账户序号|姓名|余额|账户状态|存折账号|账户序号|名称|余额|账户状态|",
                (x) => {
                    return {
                        KH: x["卡号"],
                        ZHXH: x["账户序号"],
                        XM: x["姓名"],
                        YE: x["余额"],
                        ZHZT: x["账户状态"],
                        CZZH: x["存折账号"],
                        ZHXH_1: x["账户序号"],
                        MC: x["名称"],
                        YE_1: x["余额"],
                        ZHZT_1: x["账户状态"]
                    }
                })
            output.WJ = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 文件数据项接口
 * 卡号|账户序号|姓名|余额|账户状态|存折账号|账户序号|名称|余额|账户状态|
 */
export interface E_WJ {
    /**
     * 卡号
     */
    KH: string

    /**
     * 账户序号
     */
    ZHXH: string

    /**
     * 姓名
     */
    XM: string

    /**
     * 余额
     */
    YE: string

    /**
     * 账户状态
     */
    ZHZT: string

    /**
     * 存折账号
     */
    CZZH: string

    /**
     * 账户序号(存折)
     */
    ZHXH_1: string

    /**
     * 名称
     */
    MC: string

    /**
     * 余额(存折)
     */
    YE_1: string

    /**
     * 账户状态(存折)
     */
    ZHZT_1: string
}

/**
 * 创建卡折一体信息查询功能的Vue 3组合式API封装
 */
export function useQueryKZYTXX() {
    /**
     * 通过卡号或存折号查询卡折一体详细信息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 卡折一体信息查询结果
     */
    const queryKZYTXX = (
        params: {
            KH?: string,    // 卡号
            KZZH?: string,  // 卡折账号
            ZHZT?: string   // 账户状态 1正常0开户待确认3挂失结清4开户更正5临时销户*销户#计息结束6久悬
        },
        page: any
    ): QueryKZYTXX => {
        const input = new QueryKZYTXX.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryKZYTXX>(page)
    }

    return {
        queryKZYTXX
    }
}
