import { TFInput, TFOutput } from './TFBase'

/**
 * 查询揽存登记簿
 * 查询揽存登记簿
 */
export class QueryLCDJB extends TFOutput {
    // #region Output
    /**
     * 签约明细
     * TITLE=~开户机构|账号|账户序号|金额|签约日期|截止日期|交易柜员|明细数|备注
     */
    public QYMX: string = ''

    /**
     * 签约明细
     * TITLE=~开户机构|账号|账户序号|金额|签约日期|截止日期|交易柜员|明细数|备注
     */
    public QYMXData: E_QYMX[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 账号 0300
         */
        public ZH: string = ''

        /**
         * 账户序号 0340
         */
        public ZHXH: string = ''

        /**
         * 交易机构 0910
         */
        public JYJG: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryLCDJB()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd30 = this.ZH
            this.MessageData.Fd34 = this.ZHXH
            this.MessageData.Fd91 = this.JYJG
            this.MessageData.Fd128 = "0101"

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.QYMXData = this.AnilyzeFileData<E_QYMX>(this.MessageData.FileData,
                "开户机构|账号|账户序号|金额|签约日期|截止日期|交易柜员|明细数|备注|",
                (x) => {
                    return {
                        KHJG: x["开户机构"],
                        ZH: x["账号"],
                        ZHXH: x["账户序号"],
                        JE: x["金额"],
                        QYRQ: x["签约日期"],
                        JZRQ: x["截止日期"],
                        JYGY: x["交易柜员"],
                        MXS: x["明细数"],
                        BZ: x["备注"]
                    }
                })
            output.QYMX = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 签约明细数据项接口
 * TITLE=~开户机构|账号|账户序号|金额|签约日期|截止日期|交易柜员|明细数|备注
 */
export interface E_QYMX {
    /**
     * 开户机构
     */
    KHJG: string

    /**
     * 账号
     */
    ZH: string

    /**
     * 账户序号
     */
    ZHXH: string

    /**
     * 金额
     */
    JE: string

    /**
     * 签约日期
     */
    QYRQ: string

    /**
     * 截止日期
     */
    JZRQ: string

    /**
     * 交易柜员
     */
    JYGY: string

    /**
     * 明细数
     */
    MXS: string

    /**
     * 备注
     */
    BZ: string
}

/**
 * 创建揽存登记簿查询功能的Vue 3组合式API封装
 */
export function useQueryLCDJB() {
    /**
     * 查询揽存登记簿
     * @param params 查询参数
     * @param page 页面对象
     * @returns 揽存登记簿查询结果
     */
    const queryLCDJB = (
        params: {
            ZH?: string,    // 账号
            ZHXH?: string,  // 账户序号
            JYJG?: string   // 交易机构
        },
        page: any
    ): QueryLCDJB => {
        const input = new QueryLCDJB.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryLCDJB>(page)
    }

    return {
        queryLCDJB
    }
}
