import { TFInput, TFOutput } from './TFBase'

/**
 * 大额查复报文查询
 * 根据支付行号、委托日期、序号查询大额查复报文信息
 */
export class QueryLargePackets extends TFOutput {
    // #region Output
    /**
     * 是否有记录 0660
     * 0否1是
     */
    public SFYJL: string = ''

    /**
     * 应答内容 0950
     * (null)
     */
    public YDNR: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 委托日期 0450
         * (null) 
         */
        public WTRQ: string = ''

        /**
         * 发起行行号 0580
         * (null) 
         */
        public FQXXH: string = ''

        /**
         * 非支付交易序号 0870
         * (null) 
         */
        public FZFJYXH: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryLargePackets()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K008"
            this.MessageData.Fd45 = this.WTRQ
            this.MessageData.Fd58 = this.FQXXH
            this.MessageData.Fd87 = this.FZFJYXH

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.SFYJL = this.DelSpace(this.MessageData.Fd66)
            output.YDNR = this.MessageData.Fd95

            return output
        }
    }
    // #endregion
}

/**
 * 创建大额查复报文查询功能的Vue 3组合式API封装
 */
export function useQueryLargePackets() {
    /**
     * 根据支付行号、委托日期、序号查询大额查复报文信息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 大额查复报文查询结果
     */
    const queryLargePackets = (
        params: {
            WTRQ?: string,    // 委托日期
            FQXXH?: string,   // 发起行行号
            FZFJYXH?: string  // 非支付交易序号
        },
        page: any
    ): QueryLargePackets => {
        const input = new QueryLargePackets.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryLargePackets>(page)
    }

    return {
        queryLargePackets
    }
}
