import { TFInput, TFOutput } from './TFBase'

/**
 * 9598查询-501801-查询大额支付表
 * 501801-查询大额支付表
 */
export class QueryLargePaymentList extends TFOutput {
    // #region Output
    /**
     * 查询结果
     * 文件格式:委托日期|CMT编号|交易金额|人行交易序号|发起清算行行号(账号) |付款人姓名|接收行清算行号|收款人账号|收款人姓名|交易行行号|记账账号
     */
    public CXJG: string = ''

    /**
     * 查询结果
     * 文件格式:委托日期|CMT编号|交易金额|人行交易序号|发起清算行行号(账号) |付款人姓名|接收行清算行号|收款人账号|收款人姓名|交易行行号|记账账号
     */
    public CXJGData: E_CXJG[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 查询条件 
         * 机构号
         */
        public JGH: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryLargePaymentList()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "9598"
            this.MessageData.Fd123 = `1,501801,${this.JGH}, `

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.CXJGData = this.AnilyzeFileData<E_CXJG>(this.MessageData.FileData,
                "委托日期|CMT编号|交易金额|人行交易序号|发起清算行行号(账号) |付款人姓名|接收行清算行号|收款人账号|收款人姓名|交易行行号|记账账号|",
                (x) => {
                    return {
                        WTRQ: x["委托日期"],
                        CMTBH: x["CMT编号"],
                        JYJE: x["交易金额"],
                        RXJYXH: x["人行交易序号"],
                        FQQSXXHZH: x["发起清算行行号(账号) "],
                        FKRXM: x["付款人姓名"],
                        JSXQSXH: x["接收行清算行号"],
                        SKRZH: x["收款人账号"],
                        SKRXM: x["收款人姓名"],
                        JYXXH: x["交易行行号"],
                        JZZH: x["记账账号"]
                    }
                })
            output.CXJG = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 查询结果数据项接口
 * 文件格式:委托日期|CMT编号|交易金额|人行交易序号|发起清算行行号(账号) |付款人姓名|接收行清算行号|收款人账号|收款人姓名|交易行行号|记账账号
 */
export interface E_CXJG {
    /**
     * 委托日期
     */
    WTRQ: string

    /**
     * CMT编号
     */
    CMTBH: string

    /**
     * 交易金额
     */
    JYJE: string

    /**
     * 人行交易序号
     */
    RXJYXH: string

    /**
     * 发起清算行行号(账号) 
     */
    FQQSXXHZH: string

    /**
     * 付款人姓名
     */
    FKRXM: string

    /**
     * 接收行清算行号
     */
    JSXQSXH: string

    /**
     * 收款人账号
     */
    SKRZH: string

    /**
     * 收款人姓名
     */
    SKRXM: string

    /**
     * 交易行行号
     */
    JYXXH: string

    /**
     * 记账账号
     */
    JZZH: string
}

/**
 * 创建大额支付表查询功能的Vue 3组合式API封装
 */
export function useQueryLargePaymentList() {
    /**
     * 查询大额支付表
     * @param params 查询参数
     * @param page 页面对象
     * @returns 大额支付表查询结果
     */
    const queryLargePaymentList = (
        params: {
            JGH?: string  // 机构号
        },
        page: any
    ): QueryLargePaymentList => {
        const input = new QueryLargePaymentList.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryLargePaymentList>(page)
    }

    return {
        queryLargePaymentList
    }
}
