import { TFInput, TFOutput } from './TFBase'

/**
 * 查询交易规则要素列表
 * 通过列表类型查询list_code_rel
 */
export class QueryListCodeRel extends TFOutput {
    // #region Output
    /**
     * 列表内容
     * 列表类型|列表元素描述
     */
    public LBNR: string = ''

    /**
     * 列表内容
     * 列表类型|列表元素描述
     */
    public LBNRData: E_LBNR[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 列表类型 0710
         */
        public LBLX: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryListCodeRel()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd71 = this.LBLX
            this.MessageData.Fd128 = "0025"

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.LBNRData = this.AnilyzeFileData<E_LBNR>(this.MessageData.FileData,
                "列表类型|列表元素描述|",
                (x) => {
                    return {
                        LBLX: x["列表类型"],
                        LBYSMS: x["列表元素描述"]
                    }
                })
            output.LBNR = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 列表内容数据项接口
 * 列表类型|列表元素描述
 */
export interface E_LBNR {
    /**
     * 列表类型
     */
    LBLX: string

    /**
     * 列表元素描述
     */
    LBYSMS: string
}

/**
 * 创建交易规则要素列表查询功能的Vue 3组合式API封装
 */
export function useQueryListCodeRel() {
    /**
     * 查询交易规则要素列表
     * @param params 查询参数
     * @param page 页面对象
     * @returns 交易规则要素列表查询结果
     */
    const queryListCodeRel = (
        params: {
            LBLX?: string  // 列表类型
        },
        page: any
    ): QueryListCodeRel => {
        const input = new QueryListCodeRel.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryListCodeRel>(page)
    }

    return {
        queryListCodeRel
    }
}
