import { TFInput, TFOutput } from './TFBase'

/**
 * 查询按揭欠款表
 * 根据贷款账号返回按揭贷款欠款信息
 */
export class QueryLoanArrearList extends TFOutput {
    // #region Output
    /**
     * 欠款信息列表
     * 后台返回文件，内容包括：欠款期次|欠本金|欠利息|欠罚息|还本金|还利息|还罚息|还款日期|本期本金|本期利息|
     */
    public QKXXLB: string = ''

    /**
     * 欠款信息列表
     * 后台返回文件，内容包括：欠款期次|欠本金|欠利息|欠罚息|还本金|还利息|还罚息|还款日期|本期本金|本期利息|
     */
    public QKXXLBData: E_QKXXLB[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 贷款账号 0300
         */
        public DKZH: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryLoanArrearList()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd30 = this.DKZH
            this.MessageData.Fd128 = "0030"

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.QKXXLBData = this.AnilyzeFileData<E_QKXXLB>(this.MessageData.FileData,
                "欠款期次|欠本金|欠利息|欠罚息|还本金|还利息|还罚息|还款日期|本期本金|本期利息|",
                (x) => {
                    return {
                        QKQC: x["欠款期次"],
                        QBJ: x["欠本金"],
                        QLX: x["欠利息"],
                        QFX: x["欠罚息"],
                        HBJ: x["还本金"],
                        HLX: x["还利息"],
                        HFX: x["还罚息"],
                        HKRQ: x["还款日期"],
                        BQBJ: x["本期本金"],
                        BQLX: x["本期利息"]
                    }
                })
            output.QKXXLB = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 欠款信息列表数据项接口
 * 后台返回文件，内容包括：欠款期次|欠本金|欠利息|欠罚息|还本金|还利息|还罚息|还款日期|本期本金|本期利息|
 */
export interface E_QKXXLB {
    /**
     * 欠款期次
     */
    QKQC: string

    /**
     * 欠本金
     */
    QBJ: string

    /**
     * 欠利息
     */
    QLX: string

    /**
     * 欠罚息
     */
    QFX: string

    /**
     * 还本金
     */
    HBJ: string

    /**
     * 还利息
     */
    HLX: string

    /**
     * 还罚息
     */
    HFX: string

    /**
     * 还款日期
     */
    HKRQ: string

    /**
     * 本期本金
     */
    BQBJ: string

    /**
     * 本期利息
     */
    BQLX: string
}

/**
 * 创建按揭欠款表查询功能的Vue 3组合式API封装
 */
export function useQueryLoanArrearList() {
    /**
     * 查询按揭欠款表
     * @param params 查询参数
     * @param page 页面对象
     * @returns 按揭欠款表查询结果
     */
    const queryLoanArrearList = (
        params: {
            DKZH?: string  // 贷款账号
        },
        page: any
    ): QueryLoanArrearList => {
        const input = new QueryLoanArrearList.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryLoanArrearList>(page)
    }

    return {
        queryLoanArrearList
    }
}
