import { TFInput, TFOutput } from './TFBase'

/**
 * 查询贷款信息
 * 根据贷款账号返回相关信息
 */
export class QueryLoanInfo extends TFOutput {
    // #region Output
    /**
     * 贷款信息列表
     * 后台返回文件，内容包括：还款账号|账户序号|还款类型|
     */
    public DKXXLB: string = ''

    /**
     * 贷款信息列表
     * 后台返回文件，内容包括：还款账号|账户序号|还款类型|
     */
    public DKXXLBData: E_DKXXLB[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 贷款账号 0300
         */
        public DKZH: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryLoanInfo()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd30 = this.DKZH
            this.MessageData.Fd128 = "0032"

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.DKXXLBData = this.AnilyzeFileData<E_DKXXLB>(this.MessageData.FileData,
                "还款账号|账户序号|还款类型|",
                (x) => {
                    return {
                        HKZH: x["还款账号"],
                        ZHXH: x["账户序号"],
                        HKLX: x["还款类型"]
                    }
                })
            output.DKXXLB = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 贷款信息列表数据项接口
 * 后台返回文件，内容包括：还款账号|账户序号|还款类型|
 */
export interface E_DKXXLB {
    /**
     * 还款账号
     */
    HKZH: string

    /**
     * 账户序号
     */
    ZHXH: string

    /**
     * 还款类型
     */
    HKLX: string
}

/**
 * 创建贷款信息查询功能的Vue 3组合式API封装
 */
export function useQueryLoanInfo() {
    /**
     * 查询贷款信息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 贷款信息查询结果
     */
    const queryLoanInfo = (
        params: {
            DKZH?: string  // 贷款账号
        },
        page: any
    ): QueryLoanInfo => {
        const input = new QueryLoanInfo.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryLoanInfo>(page)
    }

    return {
        queryLoanInfo
    }
}
