import { TFInput, TFOutput } from './TFBase'

/**
 * 查询贷款信息列表
 * 根据贷款账号返回相关列表信息
 */
export class QueryLoanList extends TFOutput {
    // #region Output
    /**
     * 以文件形式查询贷款账号相关信息列表
     * 序号|开户日期|产品名称|余额|账户状态|
     */
    public YWJXSCXDKZHXGXXLB: string = ''

    /**
     * 以文件形式查询贷款账号相关信息列表
     * 序号|开户日期|产品名称|余额|账户状态|
     */
    public YWJXSCXDKZHXGXXLBData: E_YWJXSCXDKZHXGXXLB[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 贷款账号 0300
         */
        public DKZH: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryLoanList()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd30 = this.DKZH
            this.MessageData.Fd128 = "0022"

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.YWJXSCXDKZHXGXXLBData = this.AnilyzeFileData<E_YWJXSCXDKZHXGXXLB>(this.MessageData.FileData,
                "序号|开户日期|产品名称|余额|账户状态|",
                (x) => {
                    return {
                        XH: x["序号"],
                        KHRQ: x["开户日期"],
                        CPMC: x["产品名称"],
                        YE: x["余额"],
                        ZHZT: x["账户状态"]
                    }
                })
            output.YWJXSCXDKZHXGXXLB = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 贷款信息列表数据项接口
 * 序号|开户日期|产品名称|余额|账户状态|
 */
export interface E_YWJXSCXDKZHXGXXLB {
    /**
     * 序号
     */
    XH: string

    /**
     * 开户日期
     */
    KHRQ: string

    /**
     * 产品名称
     */
    CPMC: string

    /**
     * 余额
     */
    YE: string

    /**
     * 账户状态
     */
    ZHZT: string
}

/**
 * 创建贷款信息列表查询功能的Vue 3组合式API封装
 */
export function useQueryLoanList() {
    /**
     * 查询贷款信息列表
     * @param params 查询参数
     * @param page 页面对象
     * @returns 贷款信息列表查询结果
     */
    const queryLoanList = (
        params: {
            DKZH?: string  // 贷款账号
        },
        page: any
    ): QueryLoanList => {
        const input = new QueryLoanList.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryLoanList>(page)
    }

    return {
        queryLoanList
    }
}
