import { TFInput, TFOutput } from './TFBase'

/**
 * 查询贷款产品信息
 * 根据贷款类别加载产品列表数据
 */
export class QueryLoanProductInfo extends TFOutput {
    // #region Output
    /**
     * 产品列表数据
     * 产品号|产品名称|币种|
     */
    public CPLBSJ: string = ''

    /**
     * 产品列表数据
     * 产品号|产品名称|币种|
     */
    public CPLBSJData: E_CPLBSJ[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 贷款期限 103A
         * 必输 
         */
        public DKQX: string = ''

        /**
         * 贷款类型 1145
         * 必输 
         */
        public DKLX: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryLoanProductInfo()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd103_A = this.DKQX
            this.MessageData.Fd114_5 = this.DKLX
            this.MessageData.Fd128 = "0016"

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.CPLBSJData = this.AnilyzeFileData<E_CPLBSJ>(this.MessageData.FileData,
                "产品号|产品名称|币种|",
                (x) => {
                    return {
                        CPH: x["产品号"],
                        CPMC: x["产品名称"],
                        BZ: x["币种"]
                    }
                })
            output.CPLBSJ = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 产品列表数据项接口
 * 产品号|产品名称|币种|
 */
export interface E_CPLBSJ {
    /**
     * 产品号
     */
    CPH: string

    /**
     * 产品名称
     */
    CPMC: string

    /**
     * 币种
     */
    BZ: string
}

/**
 * 创建贷款产品信息查询功能的Vue 3组合式API封装
 */
export function useQueryLoanProductInfo() {
    /**
     * 查询贷款产品信息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 贷款产品信息查询结果
     */
    const queryLoanProductInfo = (
        params: {
            DKQX?: string  // 贷款期限
            DKLX?: string  // 贷款类型
        },
        page: any
    ): QueryLoanProductInfo => {
        const input = new QueryLoanProductInfo.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryLoanProductInfo>(page)
    }

    return {
        queryLoanProductInfo
    }
}
