import { TFInput, TFOutput } from './TFBase'

/**
 * 按揭当前与欠款查询
 * 按揭当前与欠款查询
 */
export class QueryMortgageDebt extends TFOutput {
    // #region Output
    /**
     * 欠款本金 0390
     */
    public QKBJ: string = ''

    /**
     * 欠款利息 0400
     */
    public QKLL: string = ''

    /**
     * 欠款罚息 0410
     */
    public QKFX: string = ''

    /**
     * 本期本金 0420
     */
    public BQBJ: string = ''

    /**
     * 本期利息 0430
     */
    public BQLX: string = ''

    /**
     * 按揭列表
     * 期次|欠本金|欠利息|欠罚息|还本金|还利息|还罚息|应还日期|
     */
    public AJLB: string = ''

    /**
     * 按揭列表
     * 期次|欠本金|欠利息|欠罚息|还本金|还利息|还罚息|应还日期|
     */
    public AJLBData: E_AJLB[] = []

    /**
     * 是否按揭类型 0670
     * Y:是  N:否
     */
    public SFAJLX: string = ''

    /**
     * 本期期次 109F 天骄
     */
    public BQQC: string = ''

    /**
     * 户名 0250
     */
    public HM: string = ''

    /**
     * 借据号 0310
     */
    public JJH: string = ''

    /**
     * 表内欠息 1085
     */
    public BNQX: string = ''

    /**
     * 表外欠息 1086
     */
    public BWQX: string = ''

    /**
     * 复利欠息 1087
     */
    public FLQX: string = ''

    /**
     * 贷款现余额 1084
     */
    public DKXYE: string = ''

    /**
     * 未结本金罚息 1088
     */
    public WJBJLX: string = ''

    /**
     * 未结复利利息 1089
     */
    public WJFLLX: string = ''
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 账号 0380
         */
        public ZH: string = ''

        /**
         * 开始期数 0500
         */
        public KSQS: string = ''

        /**
         * 结束期数 0510
         */
        public JSQS: string = ''

        /**
         * 结息标志 0650
         */
        public JXBZ: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryMortgageDebt()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K044"
            this.MessageData.Fd38 = this.ZH
            this.MessageData.Fd50 = this.KSQS
            this.MessageData.Fd51 = this.JSQS
            this.MessageData.Fd65 = this.JXBZ

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.QKBJ = this.MessageData.Fd39
            output.QKLL = this.MessageData.Fd40
            output.QKFX = this.MessageData.Fd41
            output.BQBJ = this.MessageData.Fd42
            output.BQLX = this.MessageData.Fd43

            output.HM = this.MessageData.Fd25
            output.JJH = this.MessageData.Fd31
            output.DKXYE = this.MessageData.Fd108_4
            output.BNQX = this.MessageData.Fd108_5
            output.BWQX = this.MessageData.Fd108_6
            output.FLQX = this.MessageData.Fd108_7
            output.WJBJLX = this.MessageData.Fd108_8
            output.WJFLLX = this.MessageData.Fd108_9

            output.AJLBData = this.AnilyzeFileData<E_AJLB>(this.MessageData.FileData,
                "期次|欠本金|欠利息|欠罚息|还本金|还利息|还罚息|应还日期|",
                (x) => {
                    return {
                        QC: x["期次"],
                        QBJ: x["欠本金"],
                        QLX: x["欠利息"],
                        QFX: x["欠罚息"],
                        HBJ: x["还本金"],
                        HLX: x["还利息"],
                        HFX: x["还罚息"],
                        YHRQ: x["应还日期"]
                    }
                })
            output.AJLB = this.MessageData.FileData
            output.SFAJLX = this.MessageData.Fd67

            // TODO: 需要实现TT_SYSCONFIG_GetConfigValueByConfigID函数
            const FLAG = "V21" // 临时值，需要替换为实际实现
            if (FLAG === "V21" || FLAG === "V22") {
                output.BQQC = this.MessageData.Fd109_F
            }

            return output
        }
    }
    // #endregion
}

/**
 * 按揭列表数据项接口
 * 期次|欠本金|欠利息|欠罚息|还本金|还利息|还罚息|应还日期|
 */
export interface E_AJLB {
    /**
     * 期次
     */
    QC: string

    /**
     * 欠本金
     */
    QBJ: string

    /**
     * 欠利息
     */
    QLX: string

    /**
     * 欠罚息
     */
    QFX: string

    /**
     * 还本金
     */
    HBJ: string

    /**
     * 还利息
     */
    HLX: string

    /**
     * 还罚息
     */
    HFX: string

    /**
     * 应还日期
     */
    YHRQ: string
}

/**
 * 创建抵押债务查询功能的Vue 3组合式API封装
 */
export function useQueryMortgageDebt() {
    /**
     * 查询抵押债务信息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 抵押债务查询结果
     */
    const queryMortgageDebt = (
        params: {
            ZH?: string  // 账号
            KSQS?: string  // 开始期数
            JSQS?: string  // 结束期数
            JXBZ?: string  // 结息标志
        },
        page: any
    ): QueryMortgageDebt => {
        const input = new QueryMortgageDebt.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryMortgageDebt>(page)
    }

    return {
        queryMortgageDebt
    }
}
