import { TFInput, TFOutput } from './TFBase'

/**
 * 查询还款计划审批信息
 * 通过借据号查询还款计划审批表
 */
export class QueryRepaymentPlanApproval extends TFOutput {
    // #region Output
    /**
     * 还款期次
     * 还款期次|起始日期|终止日期|还本金额|
     */
    public HKQC: string = ''

    /**
     * 还款期次
     * 还款期次|起始日期|终止日期|还本金额|
     */
    public HKQCData: E_HKQC[] = []
    // #endregion

    // #region Input
    /**
     * 参数清单
     */
    public static Input = class extends TFInput {
        /**
         * 借据号 102A
         */
        public JJH: string = ''

        /**                 
         * 定义业务逻辑              
         * @returns 操作结果
         */
        public override Raise(): TFOutput {
            // 拉取数据                                  
            const output = new QueryRepaymentPlanApproval()
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd102_A = this.JJH
            this.MessageData.Fd128 = "0033"

            this.PageData.TradeAPIs.CallServer(this.MessageData)
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
            }
            output.HKQCData = this.AnilyzeFileData<E_HKQC>(this.MessageData.FileData,
                "还款期次|起始日期|终止日期|还本金额|",
                (x) => {
                    return {
                        HKQC: x["还款期次"],
                        QSRQ: x["起始日期"],
                        ZZRQ: x["终止日期"],
                        HBJE: x["还本金额"]
                    }
                })
            output.HKQC = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 还款期次数据项接口
 * 还款期次|起始日期|终止日期|还本金额|
 */
export interface E_HKQC {
    /**
     * 还款期次
     */
    HKQC: string

    /**
     * 起始日期
     */
    QSRQ: string

    /**
     * 终止日期
     */
    ZZRQ: string

    /**
     * 还本金额
     */
    HBJE: string
}

/**
 * 创建还款计划审批查询功能的Vue 3组合式API封装
 */
export function useQueryRepaymentPlanApproval() {
    /**
     * 查询还款计划审批信息
     * @param params 查询参数
     * @param page 页面对象
     * @returns 还款计划审批查询结果
     */
    const queryRepaymentPlanApproval = (
        params: {
            JJH?: string  // 借据号
        },
        page: any
    ): QueryRepaymentPlanApproval => {
        const input = new QueryRepaymentPlanApproval.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryRepaymentPlanApproval>(page)
    }

    return {
        queryRepaymentPlanApproval
    }
}
