/**
 * 根据承兑汇票协议编号查询协议信息
 * 根据承兑汇票协议编号查询承兑汇票协议详细信息
 */

/**
 * 输出参数接口
 */
export interface QueryAcceptanceAgreementNumOutput {
    /** 纸票电票标志 0200 P：纸票 E：电票 */
    ZPDPBZ: string;
    /** 付款人开户行行名 0250 */
    FKRKHXXM: string;
    /** 付款人全称 0260 */
    FKRQC: string;
    /** 收款人全称 0270 */
    SKRQC: string;
    /** 付款人开户行机构号 0300 */
    FKRKHXJGH: string;
    /** 质押协议总编号 0310 */
    ZYXYZBH: string;
    /** 保证金账号 0320 */
    BZJZH: string;
    /** 付款人账号 0380 */
    FKRZH: string;
    /** 保证金比例 0400 */
    BZJBL: string;
    /** 已签发票据总金额 0410 */
    YQFPJZJE: string;
    /** 到期日期 0440 */
    DQRQ: string;
    /** 申请日期 0460 */
    SQRQ: string;
    /** 该协议下最大编号 0480 */
    GXYXZDBH: string;
    /** 承兑汇票的记账科目（表外） 0640 */
    CDHPDJZKMBW: string;
    /** 承兑类型 0670 1：差额承兑；2：100%质押存单；3：100%保证金；4：保兑仓；5：承兑拆分 */
    CDLX: string;
    /** 协议状态 0700 9：外行的承兑汇票过来质押X:信贷审批录入1：审核；2：全部签发；3：退票修改；4:部分签发 */
    XYZT: string;
    /** 到期标志处理 0710 0：未到期处理；1：已到期处理 */
    DQBZCL: string;
    /** 是否有该协议 0720 0无 1有 */
    SFYGXY: string;
    /** 收款人行名 0810 */
    SKRXM: string;
    /** 收款人账号 0830 */
    SKRZH: string;
    /** 罚息利率 0840 */
    FXLL: string;
    /** 申请机构编码 0910 */
    SQJGBM: string;
    /** 协议金额 1001 */
    XYJE: string;
    /** 质押总金额 1002 */
    ZYZJE: string;
    /** 保证金金额 1003 */
    BZJJE: string;
    /** 银行垫款账号 1011 */
    YXDKZH: string;
    /** 银行垫款额 1013 */
    YXDKE: string;
    /** 审核柜员 0650 */
    SHGY: string;
    /** 录入柜员 0920 */
    LRGY: string;
    /** 保证金利率 0850 */
    BZJLL: string;
    /** 是否失败 */
    IsFailed: boolean;
    /** 失败原因 */
    FailureCause: string;
}

/**
 * 输入参数接口
 */
export interface QueryAcceptanceAgreementNumInput {
    /** 承兑汇票协议编号 0330 */
    CDHPXYBH: string;
}

/**
 * 承兑汇票协议查询服务
 */
export class QueryAcceptanceAgreementNumService {
    /**
     * 根据承兑汇票协议编号查询协议信息
     * @param input 输入参数
     * @returns 查询结果
     */
    public static async queryAgreement(
        input: QueryAcceptanceAgreementNumInput
    ): Promise<QueryAcceptanceAgreementNumOutput> {
        const output: QueryAcceptanceAgreementNumOutput = {
            ZPDPBZ: '',
            FKRKHXXM: '',
            FKRQC: '',
            SKRQC: '',
            FKRKHXJGH: '',
            ZYXYZBH: '',
            BZJZH: '',
            FKRZH: '',
            BZJBL: '',
            YQFPJZJE: '',
            DQRQ: '',
            SQRQ: '',
            GXYXZDBH: '',
            CDHPDJZKMBW: '',
            CDLX: '',
            XYZT: '',
            DQBZCL: '',
            SFYGXY: '',
            SKRXM: '',
            SKRZH: '',
            FXLL: '',
            SQJGBM: '',
            XYJE: '',
            ZYZJE: '',
            BZJJE: '',
            YXDKZH: '',
            YXDKE: '',
            SHGY: '',
            LRGY: '',
            BZJLL: '',
            IsFailed: false,
            FailureCause: ''
        };

        try {
            // 替换原有的后端API调用
            // const response = await api.post('/trade/queryAcceptanceAgreement', {
            //   mainCode: 'K001',
            //   cdhpXYBH: input.CDHPXYBH
            // });

            // 模拟API返回数据
            const response = {
                fd20: 'P',
                fd25: '中国银行北京分行',
                fd26: '北京某某科技有限公司',
                // 其他字段映射...
            };

            // 字段映射
            output.ZPDPBZ = this.delSpace(response.fd20);
            output.FKRKHXXM = this.delSpace(response.fd25);
            output.FKRQC = this.delSpace(response.fd26);
            // 其他字段映射...

            return output;
        } catch (error) {
            output.IsFailed = true;
            output.FailureCause = error instanceof Error ? error.message : '查询失败';
            return output;
        }
    }

    /**
     * 去除字符串中的空格
     * @param str 输入字符串
     * @returns 处理后的字符串
     */
    private static delSpace(str: string): string {
        return str ? str.replace(/\s+/g, '') : '';
    }
}
