/**
 * 查询账户计划扣划信息
 * 通过账号查询账户计划扣划信息
 */

/**
 * 账户扣划信息项接口
 */
export interface AccountDeductInfoItem {
    /** 账户序号 */
    ZHXH: string;
    /** 冻结序号 */
    DJXH: string;
    /** 扣划类型 */
    KHLX: string;
    /** 扣划周期 */
    KHZQ: string;
    /** 起始日期 */
    QSRQ: string;
    /** 终止日期 */
    ZZRQ: string;
    /** 固定扣划金额 */
    GDKHJE: string;
    /** 计划扣划总额 */
    JHKHZE: string;
    /** 已扣划总额 */
    YKHZE: string;
    /** 已扣划笔数 */
    YKHBS: string;
    /** 上次扣划日期 */
    SCKHRQ: string;
    /** 扣划机构 */
    KHJG: string;
    /** 扣划柜员 */
    KHGY: string;
    /** 备注 */
    BZ: string;
}

/**
 * 输出参数接口
 */
export interface QueryAccountDeductInfoOutput {
    /** 账户扣划信息原始数据 */
    ZHKHXX: string;
    /** 解析后的账户扣划信息列表 */
    ZHKHXXData: AccountDeductInfoItem[];
    /** 是否失败 */
    IsFailed: boolean;
    /** 失败原因 */
    FailureCause: string;
}

/**
 * 输入参数接口
 */
export interface QueryAccountDeductInfoInput {
    /** 账号 0300 */
    ZH: string;
    /** 账户序号 0340 */
    ZHXH: string;
}

/**
 * 账户扣划信息查询服务
 */
export class QueryAccountDeductInfoService {
    /**
     * 查询账户计划扣划信息
     * @param input 输入参数
     * @returns 查询结果
     */
    public static async queryDeductInfo(
        input: QueryAccountDeductInfoInput
    ): Promise<QueryAccountDeductInfoOutput> {
        const output: QueryAccountDeductInfoOutput = {
            ZHKHXX: '',
            ZHKHXXData: [],
            IsFailed: false,
            FailureCause: ''
        };

        try {
            // 替换原有的后端API调用
            // const response = await api.post('/trade/queryAccountDeduct', {
            //   mainCode: 'CXCL',
            //   zh: input.ZH,
            //   zhxh: input.ZHXH,
            //   fileType: '0012'
            // });

            // 模拟API返回数据
            const response = {
                fileData: `001|001|1|M|20230101|20231231|1000|12000|6000|6|20230630|001|1001|测试备注|`,
                // 其他字段...
            };

            // 解析文件数据
            output.ZHKHXX = response.fileData;
            output.ZHKHXXData = this.analyzeFileData(response.fileData);

            return output;
        } catch (error) {
            output.IsFailed = true;
            output.FailureCause = error instanceof Error ? error.message : '查询失败';
            return output;
        }
    }

    /**
     * 解析文件数据
     * @param fileData 文件数据
     * @returns 解析后的数据列表
     */
    private static analyzeFileData(fileData: string): AccountDeductInfoItem[] {
        if (!fileData) return [];

        const lines = fileData.split('\n').filter(line => line.trim() !== '');
        return lines.map(line => {
            const items = line.split('|').filter(item => item.trim() !== '');
            if (items.length < 14) return null;

            return {
                ZHXH: items[0],
                DJXH: items[1],
                KHLX: items[2],
                KHZQ: items[3],
                QSRQ: items[4],
                ZZRQ: items[5],
                GDKHJE: items[6],
                JHKHZE: items[7],
                YKHZE: items[8],
                YKHBS: items[9],
                SCKHRQ: items[10],
                KHJG: items[11],
                KHGY: items[12],
                BZ: items[13]
            };
        }).filter(item => item !== null) as AccountDeductInfoItem[];
    }
}
