/**
 * 查询账户详细信息
 * 查询账户详细信息
 */

/**
 * 活期账户信息接口
 */
export interface CurrentAccountInfo {
    /** 账号 */
    ZH: string;
    /** 开户行 */
    KHH: string;
    /** 客户号 */
    KHHM: string;
    /** 户名 */
    HM: string;
    /** 开户日期 */
    KHRQ: string;
    /** 产品名称 */
    CPMC: string;
    /** 账户类型 */
    ZHLX: string;
    /** 有无介质 */
    YWJZ: string;
    /** 计息类型 */
    JXLX: string;
    /** 介质状态 */
    JZZT: string;
    /** 上笔日期 */
    SBRQ: string;
    /** 账户状态 */
    ZHZT: string;
    /** 冻结状态 */
    DJZT: string;
    /** 止付状态 */
    ZFZT: string;
    /** 利息基数 */
    LXJS: string;
    /** 介质种类 */
    JZZL: string;
    /** 凭证号 */
    PZH: string;
    /** 是否凭密 */
    SFPIM: string;
    /** 证件类型 */
    ZJLX: string;
    /** 证件号码 */
    ZJHM: string;
    /** 销户行 */
    XHH: string;
    /** 销户日期 */
    XHRQ: string;
    /** 通存通兑 */
    TCTD: string;
    /** 主副标志 */
    ZFBZ: string;
    /** 主卡卡号 */
    ZKKH: string;
    /** 到期日期 */
    DQRQ: string;
    /** 冻结金额 */
    DJJE: string;
    /** 止付金额 */
    ZFJE: string;
    /** 控制金额 */
    KZJE: string;
    /** 自动转存 */
    ZDZC: string;
    /** 结算类型 */
    JSLX: string;
    /** 是否允许提现 */
    SFYXTX: string;
}

/**
 * 定期账户信息接口
 */
export interface FixedAccountInfo {
    /** 账号 */
    ZH: string;
    /** 开户行 */
    KHH: string;
    /** 客户号 */
    KHHM: string;
    /** 户名 */
    HM: string;
    /** 开户日期 */
    KHRQ: string;
    /** 产品名称 */
    CPMC: string;
    /** 账户类型 */
    ZHLX: string;
    /** 有无介质 */
    YWJZ: string;
    /** 计息类型 */
    JXLX: string;
    /** 介质状态 */
    JZZT: string;
    /** 上笔日期 */
    SBRQ: string;
    /** 账户状态 */
    ZHZT: string;
    /** 冻结状态 */
    DJZT: string;
    /** 止付状态 */
    ZFZT: string;
    /** 利息基数 */
    LXJS: string;
    /** 介质种类 */
    JZZL: string;
    /** 凭证号 */
    PZH: string;
    /** 是否凭密 */
    SFPIM: string;
    /** 证件类型 */
    ZJLX: string;
    /** 利率 */
    LL: string;
    /** 证件号码 */
    ZJHM: string;
    /** 销户行 */
    XHH: string;
    /** 销户日期 */
    XHRQ: string;
    /** 通存通兑 */
    TCTD: string;
    /** 主副标志 */
    ZFBZ: string;
    /** 主卡卡号 */
    ZKKH: string;
    /** 到期日期 */
    DQRQ: string;
    /** 冻结金额 */
    DJJE: string;
    /** 止付金额 */
    ZFJE: string;
    /** 控制金额 */
    KZJE: string;
}

/**
 * 内部账户信息接口
 */
export interface InternalAccountInfo {
    /** 账号 */
    ZH: string;
    /** 户名 */
    HM: string;
    /** 产品名称 */
    CPMC: string;
    /** 余额 */
    YE: string;
    /** 账户类型 */
    ZHLX: string;
}

/**
 * 输出参数接口
 */
export interface QueryAccountMoreInfoOutput {
    /** 内容列表原始数据 */
    NRLB: string;
    /** 解析后的活期账户信息 */
    currentAccount?: CurrentAccountInfo;
    /** 解析后的定期账户信息 */
    fixedAccount?: FixedAccountInfo;
    /** 解析后的内部账户信息 */
    internalAccount?: InternalAccountInfo;
    /** 是否失败 */
    IsFailed: boolean;
    /** 失败原因 */
    FailureCause: string;
}

/**
 * 输入参数接口
 */
export interface QueryAccountMoreInfoInput {
    /** 账号 0380 */
    ZH: string;
    /** 账户序号 0510 */
    ZHXH: string;
    /** 查询标志 0660 1活期2定期9内部 */
    CXBZ: string;
}

/**
 * 账户详细信息查询服务
 */
export class QueryAccountMoreInfoService {
    /**
     * 查询账户详细信息
     * @param input 输入参数
     * @returns 查询结果
     */
    public static async queryAccountMoreInfo(
        input: QueryAccountMoreInfoInput
    ): Promise<QueryAccountMoreInfoOutput> {
        const output: QueryAccountMoreInfoOutput = {
            NRLB: '',
            IsFailed: false,
            FailureCause: ''
        };

        try {
            // 替换原有的后端API调用
            // const response = await api.post('/trade/queryAccountMoreInfo', {
            //   mainCode: 'CXCL',
            //   zh: input.ZH,
            //   zhxh: input.ZHXH,
            //   cxbz: input.CXBZ,
            //   fileType: '0072'
            // });

            // 模拟API返回数据
            const response = {
                fileData: this.generateMockData(input.CXBZ)
            };

            // 解析文件数据
            output.NRLB = response.fileData;

            // 根据查询标志解析不同类型的数据
            switch (input.CXBZ) {
                case '1': // 活期
                    output.currentAccount = this.parseCurrentAccount(response.fileData);
                    break;
                case '2': // 定期
                    output.fixedAccount = this.parseFixedAccount(response.fileData);
                    break;
                case '9': // 内部
                    output.internalAccount = this.parseInternalAccount(response.fileData);
                    break;
            }

            return output;
        } catch (error) {
            output.IsFailed = true;
            output.FailureCause = error instanceof Error ? error.message : '查询失败';
            return output;
        }
    }

    /**
     * 解析活期账户信息
     * @param fileData 文件数据
     * @returns 活期账户信息
     */
    private static parseCurrentAccount(fileData: string): CurrentAccountInfo {
        if (!fileData) return null;

        const items = fileData.split('|').filter(item => item.trim() !== '');
        if (items.length < 31) return null;

        return {
            ZH: items[0],
            KHH: items[1],
            KHHM: items[2],
            HM: items[3],
            KHRQ: items[4],
            CPMC: items[5],
            ZHLX: items[6],
            YWJZ: items[7],
            JXLX: items[8],
            JZZT: items[9],
            SBRQ: items[10],
            ZHZT: items[11],
            DJZT: items[12],
            ZFZT: items[13],
            LXJS: items[14],
            JZZL: items[15],
            PZH: items[16],
            SFPIM: items[17],
            ZJLX: items[18],
            ZJHM: items[19],
            XHH: items[20],
            XHRQ: items[21],
            TCTD: items[22],
            ZFBZ: items[23],
            ZKKH: items[24],
            DQRQ: items[25],
            DJJE: items[26],
            ZFJE: items[27],
            KZJE: items[28],
            ZDZC: items[29],
            JSLX: items[30],
            SFYXTX: items[31]
        };
    }

    /**
     * 解析定期账户信息
     * @param fileData 文件数据
     * @returns 定期账户信息
     */
    private static parseFixedAccount(fileData: string): FixedAccountInfo {
        if (!fileData) return null;

        const items = fileData.split('|').filter(item => item.trim() !== '');
        if (items.length < 29) return null;

        return {
            ZH: items[0],
            KHH: items[1],
            KHHM: items[2],
            HM: items[3],
            KHRQ: items[4],
            CPMC: items[5],
            ZHLX: items[6],
            YWJZ: items[7],
            JXLX: items[8],
            JZZT: items[9],
            SBRQ: items[10],
            ZHZT: items[11],
            DJZT: items[12],
            ZFZT: items[13],
            LXJS: items[14],
            JZZL: items[15],
            PZH: items[16],
            SFPIM: items[17],
            ZJLX: items[18],
            LL: items[19],
            ZJHM: items[20],
            XHH: items[21],
            XHRQ: items[22],
            TCTD: items[23],
            ZFBZ: items[24],
            ZKKH: items[25],
            DQRQ: items[26],
            DJJE: items[27],
            ZFJE: items[28],
            KZJE: items[29]
        };
    }

    /**
     * 解析内部账户信息
     * @param fileData 文件数据
     * @returns 内部账户信息
     */
    private static parseInternalAccount(fileData: string): InternalAccountInfo {
        if (!fileData) return null;

        const items = fileData.split('|').filter(item => item.trim() !== '');
        if (items.length < 5) return null;

        return {
            ZH: items[0],
            HM: items[1],
            CPMC: items[2],
            YE: items[3],
            ZHLX: items[4]
        };
    }

    /**
     * 生成模拟数据
     * @param cxbz 查询标志
     * @returns 模拟数据字符串
     */
    private static generateMockData(cxbz: string): string {
        switch (cxbz) {
            case '1': // 活期
                return '622208123456789|001|C001|张三|20230101|活期储蓄|1|1|1|正常|20230630|正常|0|0|1000|01|123456789|1|01|110101199001011234|001|20231231|1|1|622208123456789|20231231|0|0|0|1|1|1|';
            case '2': // 定期
                return '622208987654321|002|C002|李四|20230201|定期一年|2|1|2|正常|20230630|正常|0|0|5000|02|987654321|1|01|0.03|110101199001011235|002|20231231|1|1|622208987654321|20231231|0|0|0|';
            case '9': // 内部
                return '9000123456|内部账户1|内部产品1|100000.00|3|';
            default:
                return '';
        }
    }
}
