/**
 * 查询账户开户信息
 * 通过账号查询账户开户信息
 */

/**
 * 联系人信息接口
 */
export interface ContactInfo {
    /** 代理人姓名 0260 */
    name: string;
    /** 代理人电话 0600 */
    phone: string;
    /** 代理人证件号码 0620 */
    idNumber: string;
    /** 代理人证件类型 0700 */
    idType: string;
}

/**
 * 输出参数接口
 */
export interface QueryAccountOpeningInformationOutput {
    /** 联系人信息 */
    contactInfo?: ContactInfo;
    /** 账户状态 0690 0：申请；1：开户；2：销户 */
    accountStatus: string;
    /** 开户确认退回原因 0820 */
    rejectReason?: string;
    /** 核准号 0880 */
    approvalNumber?: string;
    /** 备案号 0810 */
    recordNumber?: string;
    /** 信息集合 1230 */
    infoCollection?: string;
    /** 是否失败 */
    IsFailed: boolean;
    /** 失败原因 */
    FailureCause: string;
}

/**
 * 输入参数接口
 */
export interface QueryAccountOpeningInformationInput {
    /** 账号 0300 */
    accountNumber: string;
    /** 获取标志 0660 1账号联系人信息 */
    queryFlag: string;
    /** 账号序号 1022 */
    accountIndex?: string;
}

/**
 * 账户开户信息查询服务
 */
export class QueryAccountOpeningInformationService {
    /**
     * 查询账户开户信息
     * @param input 输入参数
     * @returns 查询结果
     */
    public static async queryAccountOpeningInfo(
        input: QueryAccountOpeningInformationInput
    ): Promise<QueryAccountOpeningInformationOutput> {
        const output: QueryAccountOpeningInformationOutput = {
            accountStatus: '',
            IsFailed: false,
            FailureCause: ''
        };

        try {
            // 替换原有的后端API调用
            // const response = await api.post('/trade/queryAccountOpeningInfo', {
            //   mainCode: 'K034',
            //   accountNumber: input.accountNumber,
            //   queryFlag: input.queryFlag,
            //   accountIndex: input.accountIndex
            // });

            // 模拟API返回数据
            const response = {
                data: this.generateMockData(input.queryFlag)
            };

            // 处理返回数据
            if (input.queryFlag === '1') {
                output.contactInfo = {
                    name: response.data.contactName,
                    phone: response.data.contactPhone,
                    idNumber: response.data.contactIdNumber,
                    idType: response.data.contactIdType
                };
            }

            output.accountStatus = response.data.accountStatus;
            output.rejectReason = response.data.rejectReason;
            output.approvalNumber = response.data.approvalNumber;
            output.recordNumber = response.data.recordNumber;
            output.infoCollection = response.data.infoCollection;

            return output;
        } catch (error) {
            output.IsFailed = true;
            output.FailureCause = error instanceof Error ? error.message : '查询失败';
            return output;
        }
    }

    /**
     * 生成模拟数据
     * @param queryFlag 查询标志
     * @returns 模拟数据
     */
    private static generateMockData(queryFlag: string): any {
        if (queryFlag === '1') {
            return {
                contactName: '张三',
                contactPhone: '13800138000',
                contactIdNumber: '110101199001011234',
                contactIdType: '01',
                accountStatus: '1',
                rejectReason: '',
                approvalNumber: 'HZ20230001',
                recordNumber: 'BA20230001',
                infoCollection: '开户信息集合'
            };
        } else {
            return {
                accountStatus: '1',
                rejectReason: '',
                approvalNumber: 'HZ20230001',
                recordNumber: 'BA20230001',
                infoCollection: '开户信息集合'
            };
        }
    }
}
